@@ -4,39 +4,14 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @author Vinicius Cubas Brand <vinicius@eita.org.br>
- * @author Daniel Tygel <dtygel@eita.org.br>
- *
- * @copyright 2017
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
 namespace OCA\Circles;
 
-use ArtificialOwl\MySmallPhpTools\Traits\Nextcloud\nc22\TNC22Logger;
-use ArtificialOwl\MySmallPhpTools\Traits\TArrayTools;
-use ArtificialOwl\MySmallPhpTools\Traits\TStringTools;
+use Exception;
 use OC;
 use OCA\Circles\Exceptions\CircleNotFoundException;
 use OCA\Circles\Exceptions\ContactAddressBookNotFoundException;
@@ -60,14 +35,19 @@ use OCA\Circles\Exceptions\UnknownRemoteException;
 use OCA\Circles\FederatedItems\Files\FileShare;
 use OCA\Circles\FederatedItems\Files\FileUnshare;
 use OCA\Circles\Model\Federated\FederatedEvent;
-use OCA\Circles\Model\Helpers\MemberHelper;
+use OCA\Circles\Model\Member;
 use OCA\Circles\Model\Probes\CircleProbe;
+use OCA\Circles\Model\Probes\DataProbe;
 use OCA\Circles\Model\ShareWrapper;
 use OCA\Circles\Service\CircleService;
 use OCA\Circles\Service\EventService;
 use OCA\Circles\Service\FederatedEventService;
 use OCA\Circles\Service\FederatedUserService;
+use OCA\Circles\Service\ShareTokenService;
 use OCA\Circles\Service\ShareWrapperService;
+use OCA\Circles\Tools\Traits\TArrayTools;
+use OCA\Circles\Tools\Traits\TNCLogger;
+use OCA\Circles\Tools\Traits\TStringTools;
 use OCP\Files\Folder;
 use OCP\Files\InvalidPathException;
 use OCP\Files\IRootFolder;
@@ -75,7 +55,6 @@ use OCP\Files\Node;
 use OCP\Files\NotFoundException;
 use OCP\IDBConnection;
 use OCP\IL10N;
-use OCP\ILogger;
 use OCP\IURLGenerator;
 use OCP\IUserManager;
 use OCP\Security\ISecureRandom;
@@ -84,6 +63,7 @@ use OCP\Share\Exceptions\IllegalIDChangeException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IShare;
 use OCP\Share\IShareProvider;
+use Psr\Log\LoggerInterface;
 
 /**
  * Class ShareByCircleProvider
@@ -93,73 +73,43 @@ use OCP\Share\IShareProvider;
 class ShareByCircleProvider implements IShareProvider {
 	use TArrayTools;
 	use TStringTools;
-	use TNC22Logger;
+	use TNCLogger;
 
 
 	public const IDENTIFIER = 'ocCircleShare';
 
 
-	/** @var IUserManager */
-	private $userManager;
+	private IUserManager $userManager;
+	private IRootFolder $rootFolder;
+	private IL10N $l10n;
+	private LoggerInterface $logger;
+	private IURLGenerator $urlGenerator;
+	private ShareWrapperService $shareWrapperService;
+	private ShareTokenService $shareTokenService;
+	private FederatedUserService $federatedUserService;
+	private FederatedEventService $federatedEventService;
+	private CircleService $circleService;
+	private EventService $eventService;
 
-	/** @var IRootFolder */
-	private $rootFolder;
-
-	/** @var IL10N */
-	private $l10n;
-
-	/** @var ILogger */
-	private $logger;
-
-	/** @var IURLGenerator */
-	private $urlGenerator;
-
-
-	/** @var ShareWrapperService */
-	private $shareWrapperService;
-
-	/** @var FederatedUserService */
-	private $federatedUserService;
-
-	/** @var FederatedEventService */
-	private $federatedEventService;
-
-	/** @var CircleService */
-	private $circleService;
-
-	/** @var EventService */
-	private $eventService;
-
-
-	/**
-	 * ShareByCircleProvider constructor.
-	 *
-	 * @param IDBConnection $connection
-	 * @param ISecureRandom $secureRandom
-	 * @param IUserManager $userManager
-	 * @param IRootFolder $rootFolder
-	 * @param IL10N $l10n
-	 * @param ILogger $logger
-	 * @param IURLGenerator $urlGenerator
-	 */
 	public function __construct(
 		IDBConnection $connection,
 		ISecureRandom $secureRandom,
 		IUserManager $userManager,
 		IRootFolder $rootFolder,
 		IL10N $l10n,
-		ILogger $logger,
-		IURLGenerator $urlGenerator
+		mixed $logger, // unused, only kept for compatibility with server
+		IURLGenerator $urlGenerator,
 	) {
 		$this->userManager = $userManager;
 		$this->rootFolder = $rootFolder;
 		$this->l10n = $l10n;
-		$this->logger = $logger;
+		$this->logger = OC::$server->get(LoggerInterface::class);
 		$this->urlGenerator = $urlGenerator;
 
 		$this->federatedUserService = OC::$server->get(FederatedUserService::class);
 		$this->federatedEventService = OC::$server->get(FederatedEventService::class);
 		$this->shareWrapperService = OC::$server->get(ShareWrapperService::class);
+		$this->shareTokenService = OC::$server->get(ShareTokenService::class);
 		$this->circleService = OC::$server->get(CircleService::class);
 		$this->eventService = OC::$server->get(EventService::class);
 	}
@@ -204,33 +154,30 @@ class ShareByCircleProvider implements IShareProvider {
 		}
 
 		$nodeId = $share->getNode()
-						->getId();
+			->getId();
 
 		try {
 			$knowShareWrapper = $this->shareWrapperService->searchShare($share->getSharedWith(), $nodeId);
 			throw new AlreadySharedException(
-				$this->l10n->t('This item is already shared with this circle'),
+				$this->l10n->t('This item is already shared with this team'),
 				$knowShareWrapper->getShare($this->rootFolder, $this->userManager, $this->urlGenerator)
 			);
 		} catch (ShareWrapperNotFoundException $e) {
 		}
 
 		$this->federatedUserService->initCurrentUser();
-		$circle = $this->circleService->getCircle($share->getSharedWith());
-		$owner = $circle->getInitiator();
-
-		$initiatorHelper = new MemberHelper($owner);
-		$initiatorHelper->mustBeMember();
+		$circleProbe = new CircleProbe();
+		$dataProbe = new DataProbe();
+		$dataProbe->add(DataProbe::OWNER)
+			->add(DataProbe::INITIATOR, [DataProbe::BASED_ON]);
 
+		$circle = $this->circleService->probeCircle($share->getSharedWith(), $circleProbe, $dataProbe);
 		$share->setToken($this->token(15));
+		$owner = $circle->getInitiator();
 		$this->shareWrapperService->save($share);
 
 		try {
-			$wrappedShare = $this->shareWrapperService->getShareById(
-				(int)$share->getId(),
-				$this->federatedUserService->getCurrentUser()
-			);
-
+			$wrappedShare = $this->shareWrapperService->getShareById((int)$share->getId());
 			$wrappedShare->setOwner($owner);
 		} catch (ShareWrapperNotFoundException $e) {
 			throw new ShareNotFound();
@@ -258,10 +205,14 @@ class ShareByCircleProvider implements IShareProvider {
 	public function update(IShare $share): IShare {
 		$wrappedShare = $this->shareWrapperService->getShareById((int)$share->getId());
 		$wrappedShare->setPermissions($share->getPermissions())
-					 ->setShareOwner($share->getShareOwner())
-					 ->setSharedBy($share->getSharedBy());
+			->setShareOwner($share->getShareOwner())
+			->setAttributes($share->getAttributes())
+			->setSharedBy($share->getSharedBy())
+			->setExpirationDate($share->getExpirationDate())
+			->setShareNote($share->getNote());
 
 		$this->shareWrapperService->update($wrappedShare);
+		$this->shareWrapperService->updateChildPermissions($wrappedShare);
 
 		return $wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
 	}
@@ -290,10 +241,7 @@ class ShareByCircleProvider implements IShareProvider {
 
 		$this->federatedUserService->initCurrentUser();
 		try {
-			$wrappedShare = $this->shareWrapperService->getShareById(
-				(int)$share->getId(),
-				$this->federatedUserService->getCurrentUser()
-			);
+			$wrappedShare = $this->shareWrapperService->getShareById((int)$share->getId());
 		} catch (ShareWrapperNotFoundException $e) {
 			return;
 		}
@@ -311,7 +259,7 @@ class ShareByCircleProvider implements IShareProvider {
 
 		$event = new FederatedEvent(FileUnshare::class);
 		$event->setCircle($circle)
-			  ->getParams()->sObj('wrappedShare', $wrappedShare);
+			->getParams()->sObj('wrappedShare', $wrappedShare);
 
 		$this->federatedEventService->newEvent($event);
 		$this->eventService->localShareDeleted($wrappedShare);
@@ -343,15 +291,6 @@ class ShareByCircleProvider implements IShareProvider {
 		}
 	}
 
-	/**
-	 * @param IShare $share
-	 * @param string $recipient
-	 *
-	 * @return IShare
-	 */
-	public function restore(IShare $share, string $recipient): IShare {
-		return $share;
-	}
 
 	/**
 	 * @param IShare $share
@@ -386,10 +325,35 @@ class ShareByCircleProvider implements IShareProvider {
 	}
 
 
+	/**
+	 * @param IShare $share
+	 * @param string $recipient
+	 *
+	 * @return IShare
+	 */
+	public function restore(IShare $share, string $recipient): IShare {
+		$orig = $this->shareWrapperService->getShareById((int)$share->getId());
+
+		$federatedUser = $this->federatedUserService->getLocalFederatedUser($recipient);
+		$child = $this->shareWrapperService->getChild($share, $federatedUser);
+		$this->debug('Shares::restore()', ['federatedUser' => $federatedUser, 'child' => $child]);
+
+		if ($child->getPermissions() !== $orig->getPermissions()) {
+			$child->setPermissions($orig->getPermissions());
+			$this->shareWrapperService->update($child);
+		}
+
+		$wrappedShare = $this->shareWrapperService->getShareById((int)$share->getId(), $federatedUser);
+
+		return $wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
+	}
+
+
 	/**
 	 * @param string $userId
 	 * @param Folder $node
 	 * @param bool $reshares
+	 * @param bool $shallow Whether the method should stop at the first level, or look into sub-folders.
 	 *
 	 * @return array
 	 * @throws ContactAddressBookNotFoundException
@@ -404,12 +368,13 @@ class ShareByCircleProvider implements IShareProvider {
 	 * @throws RequestBuilderException
 	 * @throws SingleCircleNotFoundException
 	 */
-	public function getSharesInFolder($userId, Folder $node, $reshares): array {
+	public function getSharesInFolder($userId, Folder $node, $reshares, $shallow = true): array {
 		$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
 		$wrappedShares = $this->shareWrapperService->getSharesInFolder(
 			$federatedUser,
-			(!is_null($node)) ? $node->getId() : 0,
-			$reshares
+			$node,
+			$reshares,
+			$shallow
 		);
 
 		$result = [];
@@ -420,6 +385,11 @@ class ShareByCircleProvider implements IShareProvider {
 			if ($wrappedShare->getFileCache()->isAccessible()) {
 				$result[$wrappedShare->getFileSource()][] =
 					$wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
+			} else {
+				$this->logger->debug('shared document is not available anymore', ['wrappedShare' => $wrappedShare]);
+				if ($wrappedShare->getFileCache()->getPath() === '') {
+					$this->logger->notice('share is not available while path is empty. might comes from an unsupported storage.', ['wrappedShare' => $wrappedShare]);
+				}
 			}
 		}
 
@@ -453,10 +423,19 @@ class ShareByCircleProvider implements IShareProvider {
 			return [];
 		}
 
-		$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
+		$nodeId = (!is_null($node)) ? $node->getId() : 0;
+
+		try {
+			$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
+		} catch (Exception $e) {
+			$this->e($e, ['userId' => $userId, 'shareType' => $shareType, 'nodeId' => $nodeId]);
+
+			return [];
+		}
+
 		$wrappedShares = $this->shareWrapperService->getSharesBy(
 			$federatedUser,
-			(!is_null($node)) ? $node->getId() : 0,
+			$nodeId,
 			$reshares,
 			$limit,
 			$offset,
@@ -513,7 +492,7 @@ class ShareByCircleProvider implements IShareProvider {
 	 * @throws RequestBuilderException
 	 */
 	public function getSharesByPath(Node $path): array {
-		$wrappedShares = $this->shareWrapperService->getSharesByFileId($path->getId());
+		$wrappedShares = $this->shareWrapperService->getSharesByFileId($path->getId(), true);
 
 		return array_filter(
 			array_map(
@@ -553,10 +532,10 @@ class ShareByCircleProvider implements IShareProvider {
 		$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
 		$probe = new CircleProbe();
 		$probe->includePersonalCircles()
-			  ->includeSystemCircles()
-			  ->mustBeMember()
-			  ->setItemsLimit((int)$limit)
-			  ->setItemsOffset((int)$offset);
+			->includeSystemCircles()
+			->mustBeMember()
+			->setItemsLimit((int)$limit)
+			->setItemsOffset((int)$offset);
 
 		$wrappedShares = $this->shareWrapperService->getSharedWith(
 			$federatedUser,
@@ -595,7 +574,35 @@ class ShareByCircleProvider implements IShareProvider {
 			throw new ShareNotFound();
 		}
 
-		return $wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
+		$share = $wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
+		if ($share->getPassword() !== '') {
+			$this->logger->notice('share is protected by a password, hash: ' . $share->getPassword());
+		}
+
+		return $share;
+	}
+
+
+	public function formatShare(IShare $share): array {
+		$this->federatedUserService->initCurrentUser();
+		$circleProbe = new CircleProbe();
+		$dataProbe = new DataProbe();
+
+		$result = ['share_with' => $share->getSharedWith()];
+		try {
+			$circle = $this->circleService->probeCircle($share->getSharedWith(), $circleProbe, $dataProbe);
+			$result['share_with_displayname'] = $circle->getDisplayName();
+		} catch (Exception $e) {
+			$this->logger->warning(
+				'Circle not found while probeCircle',
+				[
+					'sharedWith' => $share->getSharedWith(),
+					'exception' => $e
+				]
+			);
+		}
+
+		return $result;
 	}
 
 
@@ -623,15 +630,164 @@ class ShareByCircleProvider implements IShareProvider {
 
 
 	/**
+	 * if $currentAccess, returns long version of the access list:
+	 * [
+	 *   'users'  => [
+	 *     'user1' => ['node_id' => 42, 'node_path' => '/fileA'],
+	 *     'user4' => ['node_id' => 32, 'node_path' => '/folder2'],
+	 *     'user2' => ['node_id' => 23, 'node_path' => '/folder (1)'],
+	 *   ],
+	 *   'remote' => [
+	 *     'user1@server1' => ['node_id' => 42, 'token' => 'SeCr3t'],
+	 *     'user2@server2' => ['node_id' => 23, 'token' => 'FooBaR'],
+	 *   ],
+	 *   'public' => bool,
+	 *   'mail' => [
+	 *     'email1@maildomain1' => ['node_id' => 42, 'token' => 'aBcDeFg'],
+	 *     'email2@maildomain2' => ['node_id' => 23, 'token' => 'hIjKlMn'],
+	 *   ]
+	 * ]
+	 *
+	 *
+	 *
+	 *
 	 * @param Node[] $nodes
 	 * @param bool $currentAccess
 	 *
 	 * @return array
 	 */
 	public function getAccessList($nodes, $currentAccess): array {
-		return [];
+		$ids = [];
+		foreach ($nodes as $node) {
+			$ids[] = $node->getId();
+		}
+
+
+		if (!$currentAccess) {
+			return $this->getAccessListShort($ids);
+		}
+
+		$shareIds = $knownIds = $users = $remote = $mails = [];
+		foreach ($this->shareWrapperService->getSharesByFileIds($ids, true, true) as $share) {
+			$shareIds[] = $share->getId();
+			$circle = $share->getCircle();
+			foreach ($circle->getInheritedMembers() as $member) {
+				if ($share->getParent() > 0 && in_array($member->getSingleId(), $knownIds[$share->getFileSource()] ?? [])) {
+					continue;
+				}
+				$knownIds[$share->getFileSource()][] = $member->getSingleId();
+
+				switch ($member->getUserType()) {
+					case Member::TYPE_USER:
+						if ($member->isLocal()) {
+							$users[$member->getUserId()] = [
+								'node_id' => $share->getFileSource(),
+								'node_path' => $share->getFileTarget()
+							];
+						} else {
+							// we only store temp value, as token is unknown at this point
+							$remote[$member->getUserid() . '@' . $member->getInstance()] = [
+								'node_id' => $share->getFileSource(),
+								'shareId' => $share->getId(),
+								'memberId' => $member->getId(),
+							];
+						}
+						break;
+					case Member::TYPE_MAIL:
+						// we only store temp value, as token is unknown at this point
+						$mails[$member->getUserId()] = [
+							'node_id' => $share->getFileSource(),
+							'shareId' => $share->getId(),
+							'memberId' => $member->getId(),
+						];
+						break;
+				}
+			}
+		}
+
+		// list share tokens in an indexed array and update details for remote/mail entries with the correct token
+		$shareTokens = [];
+		foreach ($this->shareTokenService->getTokensFromShares(array_values(array_unique($shareIds))) as $shareToken) {
+			$shareTokens[$shareToken->getShareId()][$shareToken->getMemberId()] = $shareToken->getToken();
+		}
+
+		return [
+			'users' => $users,
+			'remote' => $this->updateAccessListTokens($remote, $shareTokens),
+			'email' => $this->updateAccessListTokens($mails, $shareTokens)
+		];
 	}
 
+	/**
+	 * returns short version of the access list:
+	 * [
+	 *   'users'  => ['user1', 'user2', 'user4'],
+	 *   'remote' => bool,
+	 *   'mail' => ['email1@maildomain1', 'email2@maildomain2']
+	 * ]
+	 *
+	 * @param array $ids
+	 *
+	 * @return array
+	 * @throws FederatedItemException
+	 * @throws RemoteInstanceException
+	 * @throws RemoteNotFoundException
+	 * @throws RemoteResourceNotFoundException
+	 * @throws RequestBuilderException
+	 * @throws UnknownRemoteException
+	 */
+	private function getAccessListShort(array $ids): array {
+		$users = $mails = [];
+		$remote = false;
+		foreach ($this->shareWrapperService->getSharesByFileIds($ids, true) as $share) {
+			if (!$share->hasCircle()) {
+				continue;
+			}
+			$circle = $share->getCircle();
+			foreach ($circle->getInheritedMembers() as $member) {
+				switch ($member->getUserType()) {
+					case Member::TYPE_USER:
+						if ($member->isLocal()) {
+							if (!in_array($member->getUserId(), $users)) {
+								$users[] = $member->getUserId();
+							}
+						} else {
+							$remote = true;
+						}
+						break;
+					case Member::TYPE_MAIL:
+						if (!in_array($member->getUserId(), $mails)) {
+							$mails[] = $member->getUserId();
+						}
+						break;
+				}
+			}
+		}
+
+		return [
+			'users' => $users,
+			'remote' => $remote,
+			'email' => $mails
+		];
+	}
+
+	/**
+	 * @param array $list
+	 * @param array<int, array<string, string>> $shareTokens
+	 *
+	 * @return array
+	 */
+	private function updateAccessListTokens(array $list, array $shareTokens): array {
+		$result = [];
+		foreach ($list as $id => $data) {
+			$result[$id] = [
+				'node_id' => $data['node_id'],
+				'token' => $shareTokens[$data['shareId']][$data['memberId']]
+			];
+		}
+
+		return $result;
+	}
 
 	/**
 	 * We don't return a thing about children.
@@ -651,25 +807,26 @@ class ShareByCircleProvider implements IShareProvider {
 	 * @return iterable
 	 */
 	public function getAllShares(): iterable {
-//		$qb = $this->dbConnection->getQueryBuilder();
-//
-//		$qb->select(' * ')
-//		   ->from('share')
-//		   ->where(
-//			   $qb->expr()
-//				  ->orX(
-//					  $qb->expr()
-//						 ->eq('share_type', $qb->createNamedParameter(IShare::TYPE_CIRCLE))
-//				  )
-//		   );
-//
-//		$cursor = $qb->execute();
-//		while ($data = $cursor->fetch()) {
-//			try {
-//				yield $this->createShareObject($data);
-//			} catch (IllegalIDChangeException $e) {
-//			};
-//		}
-//		$cursor->closeCursor();
+		//		$qb = $this->dbConnection->getQueryBuilder();
+		//
+		//		$qb->select(' * ')
+		//		   ->from('share')
+		//		   ->where(
+		//			   $qb->expr()
+		//				  ->orX(
+		//					  $qb->expr()
+		//						 ->eq('share_type', $qb->createNamedParameter(IShare::TYPE_CIRCLE))
+		//				  )
+		//		   );
+		//
+		//		$cursor = $qb->execute();
+		//		while ($data = $cursor->fetch()) {
+		//			try {
+		//				yield $this->createShareObject($data);
+		//			} catch (IllegalIDChangeException $e) {
+		//			};
+		//		}
+		//		$cursor->closeCursor();
+		return [];
 	}
 }
