@@ -278,7 +278,6 @@ OC.L10N.register(
     "Failed to load availability" : "Mistókst að hlaða inn lausum tímum",
     "Saved availability" : "Vistaði lausa tíma",
     "Failed to save availability" : "Mistókst að hlaða vista lausa tíma",
-    "Time zone:" : "Tímabelti:",
     "to" : "til",
     "Delete slot" : "Eyða tímahólfi",
     "No working hours set" : "Enginn vinnutími stilltur",
@@ -287,6 +286,10 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Veldu upphafstíma fyrir {dayName}",
     "Pick a end time for {dayName}" : "Veldu lokatíma fyrir {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setja stöðu notenda sjálfkrafa á \"Ekki ónáða\" utan þess lausa tíma sem viðkomandi er tiltækur, til að þagga niður í öllum tilkynningum.",
+    "Cancel" : "Hætta við",
+    "Import" : "Flytja inn",
+    "Error while saving settings" : "Villa við að vista stillingar",
+    "Reset to default" : "Endurstilla á sjálfgefið",
     "Availability" : "Aðgengileiki",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ef þú stillir vinnutímana þína, geta aðrir séð hvenær þú sért fjarverandi þegar þeir bóka fundi með þér.",
     "Absence" : "Fjarverandi",
@@ -303,13 +306,11 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Senda einnig tilkynningar til þeirra sem deila dagatalinu",
     "Reminders are always sent to organizers and attendees." : "Áminningar eru alltaf sendar til skipuleggjenda og þátttakenda.",
     "Enable notifications for events via push" : "Senda tilkynningar fyrir atburði sem ýtitilkynningar",
-    "Cancel" : "Hætta við",
-    "Import" : "Flytja inn",
-    "Error while saving settings" : "Villa við að vista stillingar",
     "There was an error updating your attendance status." : "Það kom upp villa við að uppfæra mætingarstöðu þína.",
     "Please contact the organizer directly." : "Hafðu samband beint við skipuleggjendurna.",
     "Are you accepting the invitation?" : "Ætlar þú að samþykkja boðið?",
     "Tentative" : "Bráðabirgða",
-    "Your attendance was updated successfully." : "Mætingarstaða þín var uppfærð."
+    "Your attendance was updated successfully." : "Mætingarstaða þín var uppfærð.",
+    "Time zone:" : "Tímabelti:"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
