@@ -52,7 +52,6 @@ OC.L10N.register(
     "Favorite files" : "Favorittfiler",
     "No favorites" : "Ingen favoritter",
     "More favorites" : "Flere favoritter",
-    "Upload (max. %s)" : "Opplasting (maks %s)",
     "Accept" : "Aksepter",
     "Reject" : "Avvis",
     "Incoming ownership transfer from {user}" : "Ny eierskapsoverføring fra {user}",
@@ -67,73 +66,62 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
     "in %s" : "om %s",
     "Transferred from %1$s on %2$s" : "Overført fra %1$s på %2$s",
-    "Files compatibility" : "Kompatibilitet med filer",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
-    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
     "File Management" : "Filbehandling",
-    "Current directory path" : "Gjeldende katalogsti",
     "Home" : "Hjem",
     "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
     "Reload current directory" : "Last inn gjeldende katalog på nytt",
     "Go to the \"{dir}\" directory" : "Gå til \"{dir}\"-katalogen",
-    "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
+    "Current directory path" : "Gjeldende katalogsti",
     "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
-    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
+    "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
     "Favorite" : "Gjør til favoritt",
     "Back" : "Tilbake",
     "Toggle selection for file \"{displayName}\"" : "Veksle valg for fil \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Veksle valg for mappe \"{displayName}\"",
     "File is loading" : "Filen lastes inn",
     "Folder is loading" : "Mappen lastes inn",
-    "Rename file" : "Gi fil nytt navn",
     "Filename" : "Filnavn",
     "Folder name" : "Mappenavn",
     "This node is unavailable" : "Denne noden er utilgjengelig",
     "Another entry with the same name already exists." : "En annen oppføring med samme navnet finnes allerede.",
     "Invalid filename." : "Ugyldig filnavn.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
-    "Unknown date" : "Ukjent dato",
+    "Rename file" : "Gi fil nytt navn",
+    "Folder" : "Mappe",
     "Pending" : "Venter",
+    "Unknown date" : "Ukjent dato",
     "Clear filter" : "Tøm filter",
     "Modified" : "Endret",
+    "Search everywhere" : "Søk overalt",
     "Type" : "Type",
     "Active filters" : "Aktivt filter",
     "Remove filter" : "Fjern filter",
     "Total rows summary" : "Sammendrag av totalrader",
+    "Toggle selection for all files and folders" : "Veksle valg for alle filer og mapper",
     "Name" : "Navn",
     "Size" : "Størrelse",
-    "Toggle selection for all files and folders" : "Veksle valg for alle filer og mapper",
     "Actions" : "Handlinger",
     "(selected)" : "(valgt)",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" feilet på noen elementer",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
-    "{count} selected" : "{count} valgt",
     "List of files and folders." : "Liste over filer og mapper.",
-    "You don’t have permission to upload or create files here." : "Du har ikke tilgang til å laste opp eller opprette filer her.",
     "You have used your space quota and cannot upload files anymore." : "Du har brukt opp lagringskvoten din og kan ikke laste opp flere filer.",
     "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper kan sorteres.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Filene gjengis når du navigerer gjennom listen.",
     "File not found" : "Finner ikke filen",
-    "Storage information" : "Informasjon om lagring",
-    "Storage quota" : "Lagringskvote",
     "{usedQuotaByte} used" : "{usedQuotaByte} brukt",
     "{used} of {quota} used" : "{used} av {quota} brukt",
     "{relative}% used" : "{relative}% brukt",
     "Could not refresh storage stats" : "Kunne ikke oppdatere lagringsstatistikk",
     "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
-    "Create" : "Opprett",
+    "Storage information" : "Informasjon om lagring",
+    "Storage quota" : "Lagringskvote",
     "New folder" : "Ny mappe",
     "Create new folder" : "Opprett ny mappe",
     "This name is already in use." : "Navnet er allerede i bruk.",
+    "Create" : "Opprett",
+    "Refresh" : "Oppdater",
+    "Limit" : "Grense",
     "Fill template fields" : "Fyll ut malfelt",
-    "Submitting fields…" : "Sender inn felt...",
     "Submit" : "Send inn",
-    "Transfer ownership of a file or folder" : "Eierskapsoverføring av en fil eller mappe",
-    "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
-    "Change" : "Endre",
-    "New owner" : "Ny eier",
     "Choose a file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
     "Transfer" : "Overfør",
     "Transfer {path} to {userid}" : "Overfør {path} til {userid}",
@@ -141,13 +129,17 @@ OC.L10N.register(
     "Unknown error" : "Ukjent feil",
     "Ownership transfer request sent" : "Forespørsel om overføring av eierskap er sendt",
     "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
+    "Transfer ownership of a file or folder" : "Eierskapsoverføring av en fil eller mappe",
+    "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
+    "Change" : "Endre",
+    "New owner" : "Ny eier",
+    "Remove extension" : "Fjern filendelse",
+    "Change file extension" : "Endre filendelse",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Å endre filendelsen fra «{old}» til «{new}» kan føre til at filen ikke kan leses.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
     "Select file or folder to link to" : "Velg fil eller mappe å koble til",
     "Choose {file}" : "Choose {file}",
-    "Loading current folder" : "Laster gjeldende mappe",
-    "Retry" : "Prøv igjen",
-    "No files in here" : "Ingen filer",
-    "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
-    "Go back" : "Gå tilbake",
     "Share" : "Del med andre",
     "Shared by link" : "Delt med lenke",
     "Shared" : "Delt",
@@ -159,59 +151,58 @@ OC.L10N.register(
     "Error during upload: {message}" : "Feil under opplasting: {message}",
     "Error during upload, status code {status}" : "Feil under opplasting, statuskode {status}",
     "Unknown error during upload" : "Ukjent feil under opplasting",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
+    "Loading current folder" : "Laster gjeldende mappe",
+    "Retry" : "Prøv igjen",
+    "No files in here" : "Ingen filer",
+    "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
+    "Go back" : "Gå tilbake",
     "Views" : "Visninger",
     "Files settings" : "Filinnstillinger",
-    "File cannot be accessed" : "Filen er ikke tilgjengelig",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen ble ikke funnet, eller du har ikke tillatelse til å vise den. Be avsenderen om å dele den.",
     "Your files" : "Dine filer",
     "Open in files" : "Åpne i filer",
+    "File cannot be accessed" : "Filen er ikke tilgjengelig",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen ble ikke funnet, eller du har ikke tillatelse til å vise den. Be avsenderen om å dele den.",
+    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
+    "General" : "Generell",
+    "All files" : "Alle filer",
+    "Personal files" : "Personlige filer",
     "Sort favorites first" : "Sorter favoritter først",
     "Sort folders before files" : "Sorter mapper før filer",
+    "Appearance" : "Utseende",
     "Show hidden files" : "Vis skjulte filer",
     "Crop image previews" : "Beskjær forhåndsvisninger av bilder",
-    "Enable the grid view" : "Aktiver rutenettvisningen",
-    "Enable folder tree" : "Aktiver mappetre",
     "Additional settings" : "Flere innstillinger",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Kopiert til utklippstavlen",
-    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
+    "Copy" : "Kopier",
     "Keyboard shortcuts" : "Tastatursnarveier",
-    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
-    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
-    "Rename a file" : "Gi nytt navn til en fil",
-    "Delete a file" : "Slett en fil",
-    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
-    "Manage tags for a file" : "Behandle merkelapper for en fil",
+    "File actions" : "Filhandlinger",
+    "Rename" : "Gi nytt navn",
+    "Delete" : "Slett",
+    "Manage tags" : "Håndtere etiketter",
     "Selection" : "Valg",
     "Select all files" : "Velg alle filer",
-    "Deselect all files" : "Velg ingen filer",
+    "Deselect all" : "Fjern all markering",
     "Navigation" : "Navigasjon",
-    "Navigate to the parent folder" : "Gå til overordnet mappe",
-    "Navigate to the file above" : "Gå til filen over",
-    "Navigate to the file below" : "Gå til filen under",
-    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
-    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
     "View" : "Vis",
-    "Toggle the grid view" : "Slå på/av rutenettvisning",
+    "Toggle grid view" : "Veksle rutenett-visning",
     "Show those shortcuts" : "Vis hurtigtastene",
-    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
-    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
+    "Files compatibility" : "Kompatibilitet med filer",
+    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
+    "Error while loading the file data" : "Feil ved lasting av fildata",
     "Owner" : "Eier",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Legg til i favoritter",
     "Tags" : "Merkelapper",
-    "You" : "Du",
-    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
-    "Error while loading the file data" : "Feil ved lasting av fildata",
+    "Blank" : "Tom",
+    "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
     "Pick a template for {name}" : "Velg en mal for {name}",
     "Create a new file with the selected template" : "Opprett en ny fil med den valgte malen",
     "Creating file" : "Oppretter fil",
-    "Blank" : "Tom",
-    "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
-    "Deletion cancelled" : "Sletting avbrutt",
     "Leave this share" : "Forlat denne delingen",
     "Leave these shares" : "Forlat disse delingene",
     "Disconnect storage" : "Koble fra lager",
@@ -222,39 +213,35 @@ OC.L10N.register(
     "Delete files" : "Slett filer",
     "Delete folder" : "Slett mappe",
     "Delete folders" : "Slett mapper",
-    "Delete" : "Slett",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er i ferd med å slette permanent {count} element","Du er i ferd med å slette permanent {count} elementer"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er i ferd med å slette {count} element","Du er i ferd med å slette {count} elementer"],
     "Confirm deletion" : "Bekreft sletting",
     "Cancel" : "Avbryt",
-    "Edit file locally" : "Rediger fil lokalt",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
-    "Retry and close" : "Prøv igjen og lukk",
-    "Edit online" : "Rediger på nett",
-    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
-    "Edit locally" : "Rediger lokalt",
+    "Download" : "Last ned",
     "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Destination is not a folder" : "Målplassering er ikke en mappe",
+    "This file/folder is already in that directory" : "Denne filen/mappen er allerede i den katalogen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe til seg selv eller til en undermappe av seg selv",
     "(copy)" : "(kopier)",
     "(copy %n)" : "(kopier %n)",
-    "Move cancelled" : "Flytt avbrutt",
     "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navnet finnes allerede i denne mappen",
     "The files are locked" : "Filene er låst",
     "The file does not exist anymore" : "Filen finnes ikke lenger",
     "Choose destination" : "Velg målplassering",
     "Copy to {target}" : "Copy to {target}",
-    "Copy" : "Kopier",
     "Move to {target}" : "Move to {target}",
     "Move" : "Flytt",
     "Move or copy operation failed" : "Flytte- eller kopieringsoperason feilet",
     "Move or copy" : "Flytt eller kopier",
-    "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
-    "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
     "Open folder {displayName}" : "Åpne mappe {displayName}",
     "Open in Files" : "Åpne i Filer",
-    "Rename" : "Gi nytt navn",
-    "Open details" : "Åpne detaljer",
+    "Open locally" : "Åpne lokalt",
+    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
+    "Open file locally" : "Åpne fil lokalt",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
+    "Retry and close" : "Prøv igjen og lukk",
+    "Details" : "Detaljer",
     "View in folder" : "Vis i mappe",
     "Today" : "I dag",
     "Last 7 days" : "Siste 7 dager",
@@ -267,9 +254,8 @@ OC.L10N.register(
     "PDFs" : "PDFer",
     "Folders" : "Mapper",
     "Audio" : "Lyd",
-    "Photos and images" : "Fotoer og bilder",
+    "Images" : "Bilder",
     "Videos" : "Filmer",
-    "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
     "Created new folder \"{name}\"" : "Opprettet ny mappe \"{name}\"",
     "Unable to initialize the templates directory" : "Kan ikke initialisere mal-mappen",
     "Create templates folder" : "Opprett malmappe",
@@ -290,22 +276,14 @@ OC.L10N.register(
     "Files moved successfully" : "Filer ble flyttet",
     "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
     "Upload cancelled" : "Opplasting avbrutt",
-    "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
-    "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
-    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Å endre filendelsen fra «{old}» til «{new}» kan føre til at filen ikke kan leses.",
-    "Change file extension" : "Endre filendelse",
-    "Keep {oldextension}" : "Behold {oldextension}",
-    "Use {newextension}" : "Bruk {newextension}",
-    "Remove extension" : "Fjern filendelse",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
+    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
     "This operation is forbidden" : "Operasjonen er forbudt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
     "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "Unexpected error: {error}" : "Uventet feil: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mappe","1 fil og {folderCount} mapper"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mappe","{fileCount} filer og 1 mappe"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
+    "_%n file_::_%n files_" : ["%n fil","%n filer"],
+    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
     "Filename must not be empty." : "Filnavn kan ikke være tomt.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tillatt i et filnavn.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reservert navn og ikke tillatt for filnavn.",
@@ -314,10 +292,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Liste over favorittfiler og mapper.",
     "No favorites yet" : "Ingen favoritter enda",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
-    "All files" : "Alle filer",
     "List of your files and folders." : "Liste over dine filer og mapper.",
-    "All folders" : "Alle mapper",
-    "Personal files" : "Personlige filer",
     "List of your files and folders that are not shared." : "Liste over dine filer og mapper som ikke er delt.",
     "No personal files found" : "Ingen personlige filer funnet",
     "Files that are not shared will show up here." : "Filer som ikke er delt vil vises her.",
@@ -325,13 +300,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liste over nylig endrede filer og mapper.",
     "No recently modified files" : "Ingen nylig endrede filer",
     "Files and folders you recently modified will show up here." : "Filer og mapper du nylig har endret, vises her.",
-    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
+    "Search" : "Søk",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Select all" : "Velg alle",
     "Upload too large" : "Filen er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
     "File could not be found" : "Filen ble ikke funnet",
-    "Download" : "Last ned",
     "Show list view" : "Vis listevisning",
     "Show grid view" : "Vis rutenett-visning",
     "Close" : "Lukk",
@@ -353,14 +327,15 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
     "Choose target folder" : "Velg målmappe",
     "Set reminder" : "Angi påminnelse",
+    "Edit locally" : "Rediger lokalt",
     "Open" : "Åpne",
     "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
-    "Details" : "Detaljer",
     "Please select tag(s) to add to the selection" : "Velg merkelapper(er) for å legge til utvalget",
     "Apply tag(s) to selection" : "Bruk merkelapp(er) på utvalget",
     "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
     "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
     "Unable to determine date" : "Kan ikke fastslå datoen",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
     "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
     "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
     "copy" : "kopier",
@@ -369,9 +344,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
     "{newName} already exists" : "{newName} finnes allerede",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
-    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
     "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
     "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
@@ -379,10 +351,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Tast inn mer enn to tegn for å lete i andre mapper",
-    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
-    "_%n file_::_%n files_" : ["%n fil","%n filer"],
     "{dirs} and {files}" : "{dirs} og {files}",
     "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
+    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
     "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
     "New" : "Ny",
     "New file/folder menu" : "Ny fil/mappe-meny",
@@ -405,24 +376,52 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
     "Path" : "Sti",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Favorisert",
+    "Favored" : "Favorittlagt",
+    "Favor" : "Favoritt",
     "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
     "Upload file" : "Last opp fil",
-    "Not favorited" : "Ikke i favoritter",
+    "Not favored" : "Ikke favorittlagt",
     "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
-    "Storage informations" : "Informasjon om lagring",
-    "Choose file" : "Velg fil",
-    "Go to the previous folder" : "Gå fil forrige mappe",
-    "Open the files app settings" : "Åpne Filer-appens innstillinger",
-    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
-    "Create new templates folder" : "Opprett ny malermappe",
-    "List of favorites files and folders." : "Liste over favorittfiler og -mapper.",
+    "Upload (max. %s)" : "Opplasting (maks %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
+    "Submitting fields…" : "Sender inn felt...",
+    "Filter filenames…" : "Filtrer filnavn...",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
+    "Enable the grid view" : "Aktiver rutenettvisningen",
+    "Enable folder tree" : "Aktiver mappetre",
+    "Copy to clipboard" : "Kopiert til utklippstavlen",
+    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
+    "Deletion cancelled" : "Sletting avbrutt",
+    "Move cancelled" : "Flytt avbrutt",
+    "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
+    "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
+    "Open details" : "Åpne detaljer",
+    "Photos and images" : "Fotoer og bilder",
+    "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mappe","1 fil og {folderCount} mapper"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mappe","{fileCount} filer og 1 mappe"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
+    "All folders" : "Alle mapper",
     "Personal Files" : "Personlige filer",
     "Text file" : "Tekstfil",
     "New text file.txt" : "Ny tekstfil.txt",
-    "Favored" : "Favorittlagt",
-    "Favor" : "Favoritt",
-    "Not favored" : "Ikke favorittlagt",
-    "Filter filenames…" : "Filtrer filnavn..."
+    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
+    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
+    "Rename a file" : "Gi nytt navn til en fil",
+    "Delete a file" : "Slett en fil",
+    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
+    "Manage tags for a file" : "Behandle merkelapper for en fil",
+    "Deselect all files" : "Velg ingen filer",
+    "Navigate to the parent folder" : "Gå til overordnet mappe",
+    "Navigate to the file above" : "Gå til filen over",
+    "Navigate to the file below" : "Gå til filen under",
+    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
+    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
+    "Toggle the grid view" : "Slå på/av rutenettvisning"
 },
 "nplurals=2; plural=(n != 1);");
