@@ -13,15 +13,12 @@ use OCP\BackgroundJob\TimedJob;
 use OCP\DirectEditing\IManager;
 
 class CleanupDirectEditingTokens extends TimedJob {
-	private const INTERVAL_MINUTES = 15 * 60;
-
-	private IManager $manager;
-
-	public function __construct(ITimeFactory $time,
-		IManager $manager) {
+	public function __construct(
+		ITimeFactory $time,
+		private IManager $manager,
+	) {
 		parent::__construct($time);
-		$this->interval = self::INTERVAL_MINUTES;
-		$this->manager = $manager;
+		$this->setInterval(15 * 60);
 	}
 
 	/**
