@@ -21,9 +21,6 @@ OC.L10N.register(
     "Mark selection as favorite" : "Marca la selecció com a preferida",
     "Add selection to favorites" : "Afegeix la selecció als preferits",
     "Remove selection from favorites" : "Suprimeix la selecció dels preferits",
-    "This name is already in use." : "Aquest nom ja s'utilitza.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no és permès dins d'un nom de fitxer.",
-    "Invalid filename." : "Nom de fitxer no vàlid.",
     "Name of the album" : "Nom de l'àlbum",
     "Location of the album" : "Lloc de l'àlbum",
     "Back" : "Torna",
