@@ -21,9 +21,6 @@ OC.L10N.register(
     "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
     "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
     "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
-    "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
-    "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Name of the album" : "Albumaren izena",
     "Location of the album" : "Albumaren kokapena",
     "Back" : "Atzera",
@@ -162,7 +159,6 @@ OC.L10N.register(
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Huts egin du {currentCollectionFileName} bildumari {newCollectionFileName}izen berria jartzean",
     "Failed to update properties of {collectionFileName} with {properties}" : "Huts egin du{collectionFileName}eguneratzean {properties} propietateak",
     "Failed to delete {collectionFileName}" : "Huts egin du {collectionFileName} ezabatzean",
-    "Failed to move {fileBaseName} to person {faceName}" : "Errorea {fileBaseName} {faceName} pertsonarengana mugitzean",
     "Failed to remove {fileBaseName}" : "Huts egin du {fileBaseName} kentzean",
     "Failed to rename {oldName} to {faceName}" : "Huts egin du {oldName} bildumari {faceName}izen berria jartzean",
     "Failed to delete {faceName}" : "Huts egin du {faceName} ezabatzean",
