@@ -34,49 +34,52 @@ OC.L10N.register(
     "Create new album" : "創建新相簿",
     "New album" : "新相簿",
     "_%n item_::_%n photos and videos_" : ["%n 個照片與視像"],
+    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
+    "Failed to update album." : "更新相簿失敗。",
     "Add people or groups who can edit your album" : "添加可以編輯您的相簿的用戶或群組",
     "Search people or groups" : "搜尋人或群組",
     "No recommendations. Start typing." : "沒有建議。開始輸入。",
-    "Group" : "群組",
-    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單中移除 {collaboratorLabel}",
     "Copy the public link" : "複製公開連結",
     "Public link copied!" : "公開連結已複製！",
     "Copy public link" : "複製公開連結",
     "Delete the public link" : "刪除公開連結",
     "Create public link share" : "建立公開連結分享",
     "Share via public link" : "透過公用連結分享",
-    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
-    "Failed to update album." : "更新相簿失敗。",
     "This collection does not exist" : "此收藏品不存在",
     "An error occurred" : "發生錯誤",
     "No picture for this day" : "這天沒有照片",
     "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
     "More photos from this day" : "更多這天的照片",
+    "_%n photos_::_%n photos_" : ["%n 張照片"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
     "Favorite" : "我的最愛",
-    "Select image {imageName}" : "選擇圖像 {imageName}",
     "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
     "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
+    "Select image {imageName}" : "選擇圖像 {imageName}",
     "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
     "Go back" : "返回",
-    "Back to {folder}" : "回到 {folder}",
-    "Share this folder" : "分享這個資料夾",
+    "Select a custom date range" : "選擇自訂日期範圍",
+    "Select a date range" : "選取日期範圍",
+    "Date range" : "日期範圍",
+    "Select filters" : "選擇過濾器",
     "Dates" : "日期",
     "Jump to specific date in list" : "跳至清單中的特定日期",
     "Jump to {date}" : "跳到 {date}",
     "Add to {destination}" : "添加到 {destination}",
+    "The destination folder is owned by {owner}" : "目標資料夾為 {owner} 擁有",
     "There are no photos or videos yet!" : "還沒有照片或視像！",
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
     "Enable squared photos view" : "啟用方形照片顯示",
     "Delete source directory" : "刪除來源目錄",
+    "Pick folder" : "挑選資料夾",
+    "Select a source folder for your media" : "選擇您媒體的來源資料夾",
     "All folders" : "所有資料夾",
     "Add a Photos source for the timelines" : "添加時間軸的照片來源",
     "Add folder" : "添加資料夾",
-    "Select a source folder for your media" : "選擇您媒體的來源資料夾",
+    "Select the default upload location for your media" : "選擇媒體的默認上傳位置",
     "Home" : "主頁",
     "Choose default Photos upload and Albums location" : "選擇默認照片上傳及相簿位置",
     "Choose a different folder" : "選擇其他資料夾",
-    "Select the default upload location for your media" : "選擇媒體的默認上傳位置",
     "View" : "檢視",
     "Media folders" : "媒體資料夾",
     "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
@@ -84,6 +87,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "_%n photo_::_%n photos_" : ["%n 張照片"],
     "Unselect all" : "取消全選",
+    "Add photos to this album" : "添加照片至此相簿",
     "Manage collaborators for this album" : "管理此相簿的協作者",
     "Open actions menu" : "打開操作選項單",
     "Edit album details" : "編輯相簿的詳細資料",
@@ -92,7 +96,6 @@ OC.L10N.register(
     "Download selected files" : "下載已選擇的檔案",
     "Remove selection from album" : "從相簿移除已選擇的範圍",
     "This album does not have any photos or videos yet!" : "此相簿還沒有任何照片或視像！",
-    "Add photos to this album" : "添加照片至此相簿",
     "Add photos to {albumName}" : "添加照片至 {albumName}",
     "Manage collaborators" : "管理協作者",
     "Save collaborators for this album." : "保存此相簿的協作者。",
@@ -113,29 +116,30 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
     "Recognized people will show up here" : "被識別的人將會出現在此處",
     "This folder does not exist" : "此資料夾不存在",
-    "Loading folders …" : "載入資料夾 …",
+    "Loading folders…" : "載入資料夾…",
     "No photos in here" : "無照片檔案",
     "Taken on {date} at {time}" : "攝於 {date} {time}",
     "This place does not have any photos or videos yet!" : "此處還沒有任何照片或影片！",
     "Add photos to this place" : "添加照片至此處",
     "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
     "There is no place yet!" : "還沒有地點！",
-    "Cover photo for shared album {albumName}." : "共享相簿 {albumName} 的封面照片。",
+    "Cover photo for shared album {albumName}" : "共享相簿 {albumName} 的封面照片",
     "Back to tags overview" : "返回標籤概覽",
     "No photos with this tag yet" : "還沒有帶有此標籤的照片",
     "No tags yet" : "尚未加入標籤",
     "Photos with tags will show up here" : "此處會顯示照片的標籤",
     "Popular tags" : "熱門標籤",
-    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
-    "Add" : "添加",
+    "All tags" : "全部標籤",
+    "Create new album from filters" : "從過濾器創建新相簿",
+    "One of the source folders does not exist" : "其中一個來源資料夾不存在",
     "Add to album" : "添加至相簿",
     "Delete selection" : "刪除所選",
     "No photos or videos in here" : "此處沒有照片或視像",
     "Unassigned faces" : "未指派的臉孔",
-    "_%n photos_::_%n photos_" : ["%n 張照片"],
     "Failed to fetch collection." : "擷取收藏品失敗。",
     "Failed to fetch collections list." : "擷取收藏品清單失敗。",
     "Failed to fetch faces list." : "擷取臉部清單失敗。",
+    "Error fetching files" : "擷取檔案時發生錯誤",
     "All your media" : "所有媒體",
     "Album {title}" : "相簿 {title}",
     "Shared Albums" : "已分享了的相簿",
@@ -144,39 +148,32 @@ OC.L10N.register(
     "Tagged photos" : "有標籤的照片",
     "Tagged photo {title}" : "有標籤的照片 {title}",
     "{title}'s face" : "{title} 的臉",
+    "Last week" : "上星期",
+    "Last Month" : "上個月",
+    "Custom…" : "自訂 ...",
     "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
     "Details" : "細節",
-    "Failed to rename {oldName} to {faceName}." : "重新命名 {oldName} 為 {faceName} 失敗。",
-    "Failed to delete {faceName}." : "刪除 {faceName} 失敗。",
-    "Failed to delete {fileId}." : "刪除 {fileId} 失敗。",
-    "Failed to delete {fileName}." : "刪除 {fileName} 失敗。",
-    "Failed to set favorite state for {fileId}." : "未能為 {fileId} 設置收藏狀態。",
-    "Failed to set favorite state for {fileName}." : "未能為 {fileName} 設置收藏狀態。",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "無法將 {fileBaseName} 添加到收藏 {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "刪除 {fileBaseName} 失敗",
+    "Failed to create {collectionFileName}" : "無法創建 {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "重新命名 {currentCollectionFileName} 為 {newCollectionFileName} 失敗",
+    "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
+    "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
+    "Failed to move {fileBaseName} to person {faceName}" : "無法將 {fileBaseName} 移動至人物 {faceName}",
+    "Failed to remove {fileBaseName}" : "無法移除 {fileBaseName}",
+    "Failed to rename {oldName} to {faceName}" : "重新命名 {oldName} 為 {faceName} 失敗",
+    "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
+    "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
+    "Failed to delete {fileName}" : "刪除 {fileName} 失敗",
+    "Failed to set favorite state for {fileId}" : "未能為 {fileId} 設置收藏狀態",
+    "Failed to set favorite state for {fileName}" : "未能為 {fileName} 設置收藏狀態",
     "Could not load photos folder" : "無法載入照片資料夾",
-    "Go back to the previous view." : "回到前一個檢視。",
-    "Go to the add collaborators view." : "到添加協作者檢視。",
-    "Create the album." : "創建相簿。",
-    "Back to the new album form." : "回到新相簿表格。",
-    "_Share with %n user_::_Share with %n users_" : ["與 %n 個用戶分享"],
-    "Search for collaborators" : "尋找協作者",
-    "Add {collaboratorLabel} to the collaborators list" : "將 {collaboratorsLabel} 添加到協作者清單",
-    "No collaborators available" : "沒有可用的協作者",
-    "Failed to fetch album." : "擷取相簿失敗。",
-    "The file is in the favorites" : "檔案在最愛中",
-    "Open the \"{name}\" sub-directory" : "開啟「{name}」子目錄",
-    "Default Photos upload and Albums location" : "默認照片上傳及相簿位置",
-    "Select the default location for your media" : "選擇媒體的默認位置",
-    "Invalid location selected" : "所選的位置無效",
-    "Photos directory" : "照片目錄",
-    "Add photos to the album" : "添加照片至相簿",
-    "Failed to fetch albums list." : "擷取相簿清單失敗。",
-    "Shared albums" : "已分享了的相簿",
-    "Create a new album" : "創建新相簿",
-    "Add selection to an album" : "將選擇範圍添加至相簿",
-    "Failed to create {albumName}." : "創建 {albumName} 失敗。",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "重新命名 {currentAlbumName} 為 {newAlbumName} 失敗。",
-    "Choose a Photos source for the timelines" : "選擇時間軸的照片來源",
-    "Media folder" : "媒體資料夾",
-    "The source folder does not exists" : "來源資料夾不存在"
+    "Group" : "群組",
+    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單中移除 {collaboratorLabel}",
+    "Back to {folder}" : "回到 {folder}",
+    "Share this folder" : "分享這個資料夾",
+    "Loading folders …" : "載入資料夾 …",
+    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
+    "Add" : "添加"
 },
 "nplurals=1; plural=0;");
