@@ -9,14 +9,14 @@ OC.L10N.register(
     "Cancel" : "Ακύρωση",
     "Add" : "Προσθήκη",
     "Name of external admin" : "Όνομα εξωτερικού διαχειριστή",
-    "Encryption" : "Κρυπτογράφηση",
-    "Edit" : "Επεξεργασία",
-    "This server is using full-disk-encryption." : "Ο διακομιστής χρησιμοποιεί κρυπτογράφηση πλήρους δίσκου.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Τα αρχεία που βρίσκονται σε εξωτερικούς αποθηκευτικούς χώρους ενδέχεται να κρυπτογραφηθούν χρησιμοποιώντας {linkopen}server-side-encryption ↗{linkclose} με κύριο κλειδί με βάση τη διαμόρφωσή τους.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Τα αρχεία σας που βρίσκονται σε εξωτερικούς αποθηκευτικούς χώρους ενδέχεται να κρυπτογραφηθούν χρησιμοποιώντας {linkopen}server-side-encryption ↗{linkclose} με ένα μεμονωμένο κλειδί με βάση τη διαμόρφωσή τους.",
     "Additionally, this server is protected with full-disk-encryption." : "Επιπλέον, αυτός ο διακομιστής προστατεύεται με κρυπτογράφηση πλήρους δίσκου.",
     "This server is protected with full-disk-encryption." : "Ο διακομιστής είναι προστατευμένος με κρυπτογράφηση πλήρους δίσκου.",
     "Your files are not protected by encryption." : "Τα αρχεία σας δεν προστατεύονται με κρυπτογράφηση.",
+    "Encryption" : "Κρυπτογράφηση",
+    "Edit" : "Επεξεργασία",
+    "This server is using full-disk-encryption." : "Ο διακομιστής χρησιμοποιεί κρυπτογράφηση πλήρους δίσκου.",
     "Privacy policy" : "Πολιτική Απορρήτου",
     "Who has access to your data?" : "Ποιός έχει πρόσβαση στα δεδομένα σας;",
     "Where is your data?" : "Πού βρίσκονται τα δεδομένα σας;",
@@ -282,12 +282,6 @@ OC.L10N.register(
     "Mayotte" : "Mayotte",
     "South Africa" : "Νότιος Αφρική",
     "Zambia" : "Ζάμπια",
-    "Zimbabwe" : "Ζιμπάμπουε",
-    "The admin has not selected the location of the server yet." : "Ο διαχειριστής δεν έχει επιλέξει ακόμη την τοποθεσία του διακομιστή.",
-    "You don't have any shares with individual users." : "Δεν έχετε μερίδια με μεμονωμένους χρήστες.",
-    "Your %s account" : "O %s λογαριασμός σας",
-    "Defining basic rights for people to control their own data in the internet age" : "Καθορισμός βασικών δικαιωμάτων για τους ανθρώπους να ελέγχουν τα δικά τους δεδομένα στην εποχή του διαδικτύου",
-    "People you shared with" : "Άτομα με κοινή χρήση",
-    "Read the privacy policy." : "Διαβάστε την πολιτική απορρήτου."
+    "Zimbabwe" : "Ζιμπάμπουε"
 },
 "nplurals=2; plural=(n != 1);");
