@@ -102,7 +102,6 @@ OC.L10N.register(
     "Administration" : "مدیریت",
     "Users" : "کاربران",
     "Additional settings" : "تنظیمات اضافی",
-    "Artificial Intelligence" : "هوش مصنوعی",
     "Administration privileges" : "اجازه‌های مدیریتی",
     "Groupware" : "کار گروهی",
     "Overview" : "نمای کلّی",
@@ -112,6 +111,7 @@ OC.L10N.register(
     "Calendar" : "تقویم",
     "Personal info" : "اطّلاعات شخصی",
     "Mobile & desktop" : "همراه و میزکار",
+    "Artificial Intelligence" : "هوش مصنوعی",
     "Email server" : "سرور ایمیل",
     "Background jobs" : "کارهای پس‌زمینه",
     "Unlimited" : "نامحدود",
@@ -123,6 +123,9 @@ OC.L10N.register(
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
     "Disabled" : "غیرفعال شده",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
+    "Logging level" : "سطح گزارش‌دهی",
+    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "سطح گزارش‌دهی روی حالت اشکال‌زدایی (debug) تنظیم شده است. از سطح اشکال‌زدایی تنها زمانی استفاده کنید که مشکلی برای تشخیص دارید، سپس سطح گزارش خود را به حالت کم‌حجم‌تری بازگردانید زیرا این حالت حجم زیادی از اطلاعات را خروجی می‌دهد و می‌تواند بر عملکرد نمونهٔ شما تأثیر منفی بگذارد.",
+    "Logging level configured correctly." : "سطح گزارش‌دهی به درستی تنظیم شد.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
     "Supported" : "پشتیبانی شده",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
@@ -133,13 +136,13 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
     "Profile information" : "اطلاعات نمایه",
     "Nextcloud settings" : "تنظیمات نکست کلود",
-    "Task:" : "Task:",
     "Enable" : "فعال",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
     "Image generation" : "Image generation",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
+    "Task:" : "Task:",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
     "Unable to modify setting" : "Unable to modify setting",
     "None" : "هیچ‌کدام",
@@ -167,6 +170,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
     "Excluded groups" : "گروه‌های مستثنی",
     "Save changes" : "ذخیرهٔ تغییرات",
+    "Default" : "پیش‌فرض",
     "Update to {update}" : "به‌روز رسانی به {update} ",
     "Remove" : "برداشتن",
     "Featured" : "برگزیده",
@@ -194,22 +198,20 @@ OC.L10N.register(
     "Description" : "شرح",
     "View in store" : "نمایش در فروشگاه",
     "Visit website" : "سر زدن به پایگاه وب",
-    "Admin documentation" : "مستندات مدیر",
-    "Developer documentation" : "مستندات توسعه‌دهندگان",
+    "Admin documentation" : "مستندات مدیریتی",
+    "Developer documentation" : "مستندات توسعه",
     "Details" : "جزییات",
     "All" : "همه",
-    "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
+    "Limit app usage to groups" : "محدودیت استفاده از برنامه به گروه‌ها",
     "No results" : "بدون نتیجه",
     "Update to {version}" : "به‌روز رسانی به {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
     "Author" : "نویسنده",
     "Categories" : "دسته‌ها",
     "Resources" : "منابع",
     "Documentation" : "مستندسازی",
     "Interact" : "تعامل",
-    "Report a bug" : "گزارش یک خطا",
+    "Report a bug" : "گزارش یک اشکال",
     "Request feature" : "درخواست ویژگی",
     "Ask questions or discuss" : "پرسش یا بحث",
     "Rate" : "رتبه‌بندی",
@@ -232,7 +234,7 @@ OC.L10N.register(
     "Devices & sessions" : "دستگاه ها و نشست ها",
     "Web, desktop and mobile clients currently logged in to your account." : "لیست دستگاه ها و نشست های فعال وارد شده با اکانت شما",
     "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
-    "App name" : "نام برنامه",
+    "App name" : "نام کاره",
     "Create new app password" : "ساختن رمزعبور برنامه جدید ",
     "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
     "Login" : "ورود",
@@ -268,7 +270,7 @@ OC.L10N.register(
     "Rename group" : "Rename group",
     "Current password" : "گذرواژه کنونی",
     "New password" : "گذرواژه جدید",
-    "Change password" : "تغییر گذر واژه",
+    "Change password" : "تغییر گذرواژه",
     "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
     "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
     "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
@@ -279,10 +281,12 @@ OC.L10N.register(
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
     "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
     "Remove profile picture" : "برداشتن نگارهٔ نمایه",
-    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
+    "The file must be a PNG or JPG" : "فرمت فایل باید PNG یا JPG باشد",
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Set as profile picture" : "به عنوان عکس نمایه تنظیم کنید",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "لطفاً توجه داشته باشید که ممکن است تا 24 ساعت طول بکشد تا عکس نمایه شما در همه جا به روز شود.",
+    "Unable to update date of birth" : "ناتوانی در به‌روزرسانی تاریخ تولد",
+    "Enter your date of birth" : "تاریخ تولدتان را وارد کنید",
     "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
     "Your full name" : "Your full name",
     "Email options" : "Email options",
@@ -326,13 +330,14 @@ OC.L10N.register(
     "Change" : "تغییر",
     "Delete" : "حذف",
     "Reshare" : "بازهم‌رسانی",
+    "School" : "مدرسه",
     "Default language" : "زبان پیش فرض",
     "Common languages" : "زبانهای رایج",
     "Other languages" : "Other languages",
     "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
     "No accounts" : "حسابی وجود ندارد",
     "Manager" : "Manager",
-    "Display name" : "نمایش نام",
+    "Display name" : "نام نمایشی",
     "Either password or email is required" : "Either password or email is required",
     "Password (required)" : "Password (required)",
     "Email (required)" : "Email (required)",
@@ -346,14 +351,13 @@ OC.L10N.register(
     "Scroll to load more rows" : "Scroll to load more rows",
     "Password or insufficient permissions message" : "Password or insufficient permissions message",
     "Avatar" : "آواتار",
-    "Account name" : "Account name",
+    "Account name" : "نام حساب.",
     "Group admin for" : "مدیر گروه برای",
     "Storage location" : "محل ذخیره سازی",
     "Last login" : "آخرین ورود",
     "Account actions" : "اقدامات حساب",
     "{size} used" : "{size} مورد استفاده",
     "Resend welcome email" : "ارسال ایمیل خوش آمدید",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
     "Remote wipe of devices" : "پاک کردن از راه دور دستگاه ها",
     "Wipe {userid}'s devices" : "دستگاه های {userid} را پاک کنید",
     "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
@@ -365,7 +369,7 @@ OC.L10N.register(
     "Email was successfully changed" : "Email was successfully changed",
     "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
     "Set the language" : "Set the language",
-    "Done" : "انجام شد",
+    "Done" : "Done",
     "Edit" : "ویرایش",
     "Visibility" : "Visibility",
     "Show language" : "Show language",
@@ -387,8 +391,14 @@ OC.L10N.register(
     "No devices configured." : "No devices configured.",
     "The following devices are configured for your account:" : "The following devices are configured for your account:",
     "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
+    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
+    "Try again" : "تلاش دوباره",
+    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
+    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
+    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
+    "Apply" : "اعمال",
     "All accounts" : "همهٔ حساب‌ها",
     "Admins" : "مدیران",
     "Sending…" : "در حال ارسال",
@@ -396,9 +406,10 @@ OC.L10N.register(
     "Location" : "مکان",
     "Profile picture" : "تصویر پروفایل",
     "About" : "درباره",
+    "Date of birth" : "تاریخ تولد",
     "Full name" : "نام کامل",
     "Additional email" : "Additional email",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
+    "Fediverse (e.g. Mastodon)" : "فدیورس (مانند ماستودون)",
     "Headline" : "عنوان",
     "Organisation" : "سازمان",
     "Phone number" : "شماره تلفن",
@@ -407,6 +418,7 @@ OC.L10N.register(
     "Website" : "وب‌ سایت",
     "Profile visibility" : "امکان دیده شدن پروفایل",
     "Locale" : "محل",
+    "First day of week" : "نخستین روز هفته",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
     "Your apps" : "برنامه‌های شما",
     "Active apps" : "برنامه‌های فعال",
@@ -422,7 +434,6 @@ OC.L10N.register(
     "Disable" : "غیرفعال",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
     "Unknown" : "ناشناخته",
     "Never" : "هرگز",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
@@ -455,14 +466,6 @@ OC.L10N.register(
     "SMTP Password" : "رمز عبور SMTP",
     "Save" : "ذخیره",
     "Test and verify email settings" : "Test and verify email settings",
-    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
-    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
-    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
-    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
-    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید",
     "Reasons to use Nextcloud in your organization" : "دلایلی برای استفاده از نکست‌کلود در سازمان شما",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose}، {githubopen} کد منبع {linkclose} تحت مجوز {licenseopen}AGPL{linkclose}است. ",
     "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
@@ -474,8 +477,16 @@ OC.L10N.register(
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "برای اجرای این بررسی، باید مطمئن شوید که وب‌سرور شما می‌تواند به خودش متصل شود. بنابراین باید بتواند حداقل یکی از `trusted_domains` یا `overwrite.cli.url` خود را حل و به آن متصل شود. این خطا ممکن است نتیجه عدم تطابق DNS سمت سرور یا قانون فایروال خروجی باشد.",
     "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
     "Your biography" : "بیوگرافی شما",
     "You are using <strong>{usage}</strong>" : "فضای مورد استفاده: <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید"
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
+    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید"
 },
 "nplurals=2; plural=(n > 1);");
