@@ -1,6 +1,13 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privat",
+    "Local" : "Local",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificacion…",
     "Unable to change password" : "Cambiament impossible del senhal",
     "Very weak password" : "Senhal plan feble",
     "Weak password" : "Senhal feble",
@@ -63,8 +70,6 @@ OC.L10N.register(
     "Background jobs" : "Prètzfaches de rèireplan",
     "Unlimited" : "Illimitat",
     "Verifying" : "Verificacion",
-    "Verifying …" : "Verificacion…",
-    "Verify" : "Verificar",
     "Disabled" : "Desactivat",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
@@ -131,14 +136,14 @@ OC.L10N.register(
     "Picture provided by original account" : "Imatge provesit pel compte d’origina",
     "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
     "Your full name" : "Vòstre nom complèt",
-    "No email address set" : "Cap d’adreça pas definida",
     "Email options" : "Opcions d’email",
     "This address is not confirmed" : "Aquesta adreça es pas confirmada",
     "Set as primary email" : "Definir coma adreça principala",
+    "No email address set" : "Cap d’adreça pas definida",
     "Your headline" : "Vòstre títol",
-    "No language set" : "Cap de lenga pas definida",
     "Unable to update language" : "Actualizacion de la lenga impossibla",
     "Help translate" : "Ajudar a traduire",
+    "No language set" : "Cap de lenga pas definida",
     "Week starts on {firstDayOfWeek}" : "La setmana comença lo {firstDayOfWeek}",
     "Your organisation" : "Vòstra organizacion",
     "Your phone number" : "Vòstre numèro de telefòn",
@@ -167,6 +172,7 @@ OC.L10N.register(
     "Show last login" : "Afichar la darrièra connexion",
     "Send email" : "Enviar email",
     "Default quota" : "Quota per defaut",
+    "Adding your device …" : "Apondon del periferic…",
     "Unnamed device" : "Periferic sens nom",
     "Passwordless Authentication" : "Autentificacion sens senhal",
     "No devices configured." : "Cap de periferic pas configurat.",
@@ -187,11 +193,6 @@ OC.L10N.register(
     "Website" : "Site web",
     "Profile visibility" : "Visibilitat perfil",
     "Locale" : "Varianta lingüistica",
-    "Private" : "Privat",
-    "Local" : "Local",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
     "Your apps" : "Vòstras aplicacions",
     "Active apps" : "Aplicacions activas",
     "Disabled apps" : "Aplicacions desactivadas",
@@ -221,7 +222,6 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "S’abonar a l’infoletra",
     "Set default expiration date for shares" : "Definir una data d’expiracion per defaut pels partatges",
     "Your biography" : "Vòstra biografia",
-    "You are using <strong>{usage}</strong>" : "Utilizatz <strong>{usage}</strong>",
-    "Adding your device …" : "Apondon del periferic…"
+    "You are using <strong>{usage}</strong>" : "Utilizatz <strong>{usage}</strong>"
 },
 "nplurals=2; plural=(n > 1);");
