@@ -26,9 +26,11 @@ OC.L10N.register(
     "Close outline view" : "Затвори преглед",
     "Outline" : "Преглед",
     "Enter your name so other people can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
-    "Edit guest name" : "Промени име на гостин",
+    "Enter your name" : "Внесете го вашето име",
     "Guest" : "Гостин",
-    "Save guest name" : "Зачувај име на гостин",
+    "submit" : "испрати",
+    "you" : "ти",
+    "edit" : "уреди",
     "Insert an attachment" : "Вметни прилог",
     "Active people" : "Активни луѓе",
     "guest" : "гостин",
@@ -104,6 +106,8 @@ OC.L10N.register(
     "Use current version" : "Користи ја моменталната верзија",
     "Use the saved version" : "Користи ја зачуваната верзија",
     "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
+    "Edit guest name" : "Промени име на гостин",
+    "Save guest name" : "Зачувај име на гостин",
     "Info" : "Инфо",
     "Success" : "Успешно",
     "Warning" : "Предупредување"
