@@ -41,16 +41,22 @@ OC.L10N.register(
     "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
     "Close outline view" : "关闭大纲视图",
     "Outline" : "大纲",
+    "Not connected. Cannot update guest name." : "未连接。无法更新访客名称。",
+    "Failed to update the guest name." : "无法更新访客名称。",
     "Enter your name so other people can see who is editing" : "输入你的名称来让其他用户可以看到是谁在编辑。",
-    "Edit guest name" : "编辑访客姓名",
+    "Enter your name" : "输入名称",
     "Guest" : "访客",
-    "Save guest name" : "保存访客姓名",
+    "submit" : "提交",
+    "you" : "你",
+    "edit" : "编辑",
     "Uploading multiple attachments failed." : "上传多个附件失败。",
     "Uploading attachment failed: {error}" : "上传附件失败：{error}",
     "Uploading attachment failed." : "上传附件失败。",
     "Insert an attachment" : "插入附件",
     "Failed to insert from Files" : "无法从文件插入",
     "Failed to create attachment" : "无法创建附件",
+    "Offline since {time}." : "自 {time} 起离线。",
+    "Not connected to the cloud." : "未连接到云端。",
     "Preview options" : "预览选项",
     "Text only" : "仅文字",
     "Show link preview" : "显示链接预览",
@@ -58,7 +64,6 @@ OC.L10N.register(
     "Remove link" : "删除链接",
     "Active people" : "活动用户",
     "guest" : "访客",
-    "Full width editor" : "全宽编辑器",
     "Open the Smart Picker" : "打开智能选择器",
     "Offline" : "离线",
     "Offline, changes will be saved when online" : "离线，更改将会在上线后保存",
@@ -118,10 +123,12 @@ OC.L10N.register(
     "Alt" : "Alt",
     "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
     "Copy link to clipboard" : "复制链接到剪贴板",
+    "Open link" : "打开链接",
     "Edit link" : "编辑链接",
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Disabled because you are currently offline." : "已禁用，因为您当前已离线。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "无法创建或上传附件，因为此文件是从另一个云共享的。",
     "Upload from computer" : "从电脑上传",
     "Insert from Files" : "从文件插入",
@@ -129,11 +136,13 @@ OC.L10N.register(
     "Link to file or folder" : "链接至文件或文件夹",
     "Link to website" : "链接至网站",
     "Update link" : "更新链接",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
     "_%n word_::_%n words_" : ["%n 字"],
     "_%n char_::_%n chars_" : ["%n 字符"],
     "Remaining actions" : "重命名操作",
     "Editor actions" : "编辑器操作",
     "Formatting menu bar" : "格式化菜单栏",
+    "Full width editor" : "全宽编辑器",
     "Translate from {language}" : "翻译自 {language}",
     "Translate to {language}" : "翻译至 {language}",
     "Translation failed" : "翻译失败",
@@ -220,6 +229,8 @@ OC.L10N.register(
     "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
     "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
     "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
+    "Edit guest name" : "编辑访客姓名",
+    "Save guest name" : "保存访客姓名",
     "Detect language" : "检测语言",
     "Callouts" : "标注",
     "Info" : "信息",
