@@ -23,12 +23,14 @@ OC.L10N.register(
     "Checking apps for compatible versions" : "Es werden alle Apps auf kompatible Versionen geprüft",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bitte sicherstellen, dass in der \"config.php\"-Datei die Variable <samp>appstoreenabled</samp> nicht auf \"false\" steht.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Die Verbindung zum App-Store konnte nicht aufgebaut werden oder der App-Store hat keine Apps zurück geliefert. Selbst nach Updates suchen oder sicherstellen, dass der Server Zugriff auf das Internet hat und eine Verbindung zum App-Store aufbauen kann.",
-    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "Für <strong>alle</strong> Apps steht eine kompatible Version zur Verfügung.",
-    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps stehen keine kompatible Versionen zur Verfügung."],
+    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "Für <strong>alle</strong> Apps steht eine kompatible Version für diese {productName}-Version zur Verfügung.",
+    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version für diese {productName}-Version zur Verfügung.","Für <strong>%n</strong> Apps steht keine kompatible Version für diese {productName}-Version  zur Verfügung."],
     "Enterprise" : "Version für Unternehmen",
-    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Für den Einsatz in Unternehmen. Stellt immer die neueste Patch-Version bereit, wird jedoch nicht sofort auf die nächste Hauptversion aktualisiert. Diese Aktualisierung wird durchgeführt, sobald die Nextcloud GmbH zusätzliche Vorbereitungen und Tests für umfangreiche und unternehmenskritische Software-Verteilungen durchgeführt hat. Dieser Kanal steht nur Kunden zur Verfügung und enthält das Nextcloud Firmen-Paket .",
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Für den Einsatz in Unternehmen. Bietet immer die neueste Patch-Ebene, wird aber nicht sofort auf die nächste Hauptversion aktualisiert.",
+    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "Dieses Update wird druchgeführt, sobald {vendor} zusätzliche Härtungen und Tests für groß angelegte und unternehmenskritische Einsätze durchgeführt hat.",
+    "This channel is only available to customers and provides the {enterprise} package." : "Dieser Kanal steht nur Kunden zur Verfügung und stellt das {enterprise}-Paket bereit.",
     "Stable" : "Stabil",
-    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Die aktuellste stabile Version. Diese ist für den regelmäßigen Gebrauch geeignet und wird immer auf die letzte Hauptversion aktualisiert.",
+    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Die aktuellste stabile Version. Diese ist für den regelmäßigen Gebrauch geeignet und wird immer auf die neueste Hauptversion aktualisiert.",
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Eine Vorabversion die einzig zum Testen neuer Funktionen dient, nicht aber für den Einsatz in Produktivumgebungen geeignet ist.",
     "Update" : "Aktualisieren",
@@ -49,13 +51,16 @@ OC.L10N.register(
     "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Das Ändern des Update-Kanals wirkt sich auch auf die Verwaltungsseite der Apps aus. So werden z.B. nach dem Wechsel auf den Beta-Kanal auf der App-Verwaltungsseite Beta-App-Updates angeboten.",
     "Current update channel:" : "Aktueller Update-Kanal:",
     "You can always update to a newer version. But you can never downgrade to a more stable version." : "Es kann immer auf eine neuere Version aktualisiert werden. Jedoch kann kein Downgrade auf eine stabilere Version erfolgen. ",
-    "Notify members of the following groups about available updates:" : "Informiere die Mitglieder der folgenden Gruppen über verfügbare Updates:",
+    "Notify members of the following groups about available updates:" : "Die Mitglieder der folgenden Gruppen über verfügbare Updates informieren:",
     "No groups" : "Keine Gruppen",
     "Only notifications for app updates are available." : "Benachrichtigungen sind nur für Aktualisierungen von Apps verfügbar.",
     "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Aktualisierungskanal macht dedizierte Benachrichtigungen für Server Aktualisierungen obsolet.",
     "The selected update channel does not support updates of the server." : "Der gewählte Aktualisierungskanal unterstützt keine Aktualisierungen für Server.",
     "Changelog for app {app}" : "Änderungsübersicht für App {app}",
     "What's new in {app} version {version}" : "Neuigkeiten in {app} Version {version}",
-    "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Weitere Informationen zur Aktualisierung."
+    "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Weitere Informationen zur Aktualisierung.",
+    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "Für <strong>alle</strong> Apps steht eine kompatible Version zur Verfügung.",
+    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps stehen keine kompatible Versionen zur Verfügung."],
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Für den Einsatz in Unternehmen. Stellt immer die neueste Patch-Version bereit, wird jedoch nicht sofort auf die nächste Hauptversion aktualisiert. Diese Aktualisierung wird durchgeführt, sobald die Nextcloud GmbH zusätzliche Vorbereitungen und Tests für umfangreiche und unternehmenskritische Software-Verteilungen durchgeführt hat. Dieser Kanal steht nur Kunden zur Verfügung und enthält das Nextcloud Firmen-Paket ."
 },
 "nplurals=2; plural=(n != 1);");
