@@ -6,10 +6,14 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Montrez vos dernières photos et vidéos de vacances comme au cinéma, montrez un aperçu de votre dernier roman directement depuis votre Nextcloud, choisissez le meilleur GIF de votre collection grâce à l'aperçu direct de vos fichiers favoris et bien d'autres choses encore !",
     "Your browser does not support audio." : "Votre navigateur web ne prend pas en charge l'audio.",
     "Error loading {name}" : "Erreur au chargement de {name}",
+    "You are about to overwrite the original file. Are you sure you want to continue?" : "Vous êtes sur le point de remplacer le fichier d'origine. Voulez-vous vraiment continuer ?",
+    "A file with this name already exists. Do you want to overwrite it?" : "Un fichier portant ce nom existe déjà. Voulez-vous le remplacer ?",
+    "Confirm overwrite" : "Confirmer le remplacement",
+    "Cancel" : "Annuler",
+    "Overwrite" : "Remplacer",
+    "An error occurred while trying to confirm the file overwrite." : "Une erreur est survenue lors de la tentative de confirmation du remplacement du fichier",
     "Image saved" : "Image sauvegardée",
     "Error saving image" : "Erreur lors de l'enregistrement de l'image",
-    "Unsaved changes" : "Modifications non enregistrées",
-    "Drop changes" : "Abandonner les changements",
     "Play the live photo" : "Lire la live photo",
     "LIVE" : "EN DIRECT",
     "Your browser does not support videos." : "Votre navigateur ne prend pas en charge les vidéos.",
@@ -30,7 +34,6 @@ OC.L10N.register(
     "Reset" : "Réinitialiser",
     "All changes will be lost." : "Tous les changements seront perdus.",
     "Are you sure you want to continue?" : "Êtes-vous sûr de vouloir continuer ?",
-    "Cancel" : "Annuler",
     "Apply" : "Appliquer",
     "Warning" : "Avertissement",
     "Confirm" : "Confirmer",
@@ -77,8 +80,8 @@ OC.L10N.register(
     "Image" : "Image",
     "Importing …" : "Importation...",
     "+ Add image" : "+ Ajouter une image",
-    "Upload image" : "Téléversement d'image",
-    "From gallery" : "De la galerie",
+    "Upload image" : "Téléverser l'image",
+    "From gallery" : "Depuis la galerie",
     "Line" : "Ligne",
     "Pen" : "Stylo",
     "Polygon" : "Polygone",
@@ -99,7 +102,7 @@ OC.L10N.register(
     "Line height" : "Hauteur de ligne",
     "Warmth" : "Température",
     "+ Add watermark" : "+ Ajouter un filigrane",
-    "+ Add text watermark" : "+ Ajouter un texte filigraner",
+    "+ Add text watermark" : "+ Ajouter un filigrane texte",
     "Choose watermark type" : "Choisir un type de filigrane",
     "Upload watermark" : "Téléverser un filigrane",
     "Add as text" : "Ajouter comme texte",
@@ -125,7 +128,7 @@ OC.L10N.register(
     "Failed to load image." : "Échec du chargement de l'image.",
     "Menu" : "Menu",
     "Width" : "Largeur",
-    "Height" : "Taille",
-    "No preview available for this crop item" : "Aucun aperçu disponible pour cet élément de recadrage"
+    "Height" : "Hauteur",
+    "No preview available for this crop item" : "Aucun aperçu disponible pour cet élément recadré"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
