@@ -81,8 +81,6 @@ OC.L10N.register(
     "Already up to date" : "Ja teniu la versió més recent",
     "Unknown" : "Desconegut",
     "PNG image" : "Imatge PNG",
-    "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
     "unknown text" : "text desconegut",
     "Hello world!" : "Hola a tothom!",
     "sunny" : "assolellat",
@@ -111,7 +109,6 @@ OC.L10N.register(
     "Federated user" : "Usuari federat",
     "user@your-nextcloud.org" : "usuari@el-teu-nextcloud.org",
     "Create share" : "Crea l'element compartit",
-    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls",
     "Please copy the link manually:" : "Copieu l'enllaç manualment:",
     "Custom date range" : "Interval de dates personalitzat",
     "Pick start date" : "Trieu la data d'inici",
@@ -378,6 +375,8 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància del %s està actualment en mode de manteniment i podria estar-ho una estona.",
     "This page will refresh itself when the instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància torni a estar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o si apareix inesperadament.",
+    "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, pantalla compartida, reunions en línia i conferències per Internet; en el navegador i amb aplicacions mòbils.",
     "You have not added any info yet" : "Encara no heu afegit cap informació",
     "{user} has not added any info yet" : "{user} encara no ha afegit cap informació",
@@ -400,6 +399,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Canvia la visibilitat de la contrasenya",
     "Configure the database" : "Configuració de la base de dades",
     "Only %s is available." : "Només hi ha disponible %s.",
-    "Database account" : "Compte de base de dades"
+    "Database account" : "Compte de base de dades",
+    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls"
 },
 "nplurals=2; plural=(n != 1);");
