@@ -18,6 +18,10 @@ OC.L10N.register(
     "Unknown filetype" : "نامەلۇم ھۆججەت شەكلى",
     "An error occurred. Please contact your admin." : "خاتالىق كۆرۈلدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
     "Invalid image" : "ئىناۋەتسىز رەسىم",
+    "No temporary profile picture available, try again" : "ۋاقىتلىق ئارخىپ رەسىمى يوق ، قايتا سىناڭ",
+    "No crop data provided" : "زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
+    "No valid crop data provided" : "ئۈنۈملۈك زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
+    "Crop is not square" : "زىرائەت چاسا ئەمەس",
     "State token does not match" : "دۆلەت بەلگىسى ماس كەلمەيدۇ",
     "Invalid app password" : "ئىناۋەتلىك ئەپ مەخپىي نومۇرى",
     "Could not complete login" : "كىرىشنى تاماملىيالمىدى",
@@ -76,6 +80,13 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "تۆۋەندىكى ئەپلەر چەكلەنگەن:% s",
     "Already up to date" : "ئاللىبۇرۇن يېڭىلاندى",
     "Unknown" : "نامەلۇم",
+    "unknown text" : "نامەلۇم تېكىست",
+    "Hello world!" : "ياخشىمۇسىز دۇنيا!",
+    "sunny" : "ئاپتاپپەرەس",
+    "Hello {name}, the weather is {weather}" : "ياخشىمۇسىز {name} ، ھاۋارايى {weather}",
+    "Hello {name}" : "ياخشىمۇسىز {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong> بۇلار سىزنىڭ ئىزدەش نەتىجىلىرىڭىز <script> ئاگاھلاندۇرۇش (1) </script> </strong>",
+    "new" : "new",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "يېڭىلاش ئېلىپ بېرىلىۋاتىدۇ ، بۇ بەتتىن ئايرىلىش بەزى مۇھىتتىكى جەرياننى قالايمىقانلاشتۇرۇشى مۇمكىن.",
     "Update to {version}" : "{version} يېڭىلاش}",
     "An error occurred." : "خاتالىق كۆرۈلدى.",
@@ -102,6 +113,7 @@ OC.L10N.register(
     "Search in current app" : "نۆۋەتتىكى ئەپتىن ئىزدەڭ",
     "Clear search" : "ئىزدەشنى تازىلاش",
     "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
+    "Searching …" : "ئىزدەش…",
     "Start typing to search" : "ئىزدەشنى باشلاڭ",
     "No matching results" : "ماس كېلىدىغان نەتىجە يوق",
     "Today" : "بۈگۈن",
@@ -120,6 +132,7 @@ OC.L10N.register(
     "Load more results" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەڭ",
     "Search in" : "ئىزدەڭ",
     "Log in" : "كىرىڭ",
+    "Logging in …" : "تىزىمغا كىرىش…",
     "Log in to {productName}" : "{productName} to غا كىرىڭ",
     "Wrong login or password." : "كىرىش ياكى پارول خاتا.",
     "This account is disabled" : "بۇ ھېسابات چەكلەنگەن",
@@ -153,16 +166,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "كوللابورا تورىدا قۇرۇلغان ھەمكارلىق ھۆججەتلىرى ، ئېلېكترونلۇق جەدۋەل ۋە تونۇشتۇرۇشلار.",
     "Distraction free note taking app." : "دىققىتى چېچىلىدىغان ھەقسىز خاتىرە ئېلىش دېتالى.",
     "Recommended apps" : "تەۋسىيە قىلىنغان ئەپلەر",
+    "Loading apps …" : "ئەپلەرنى يۈكلەۋاتىدۇ…",
     "Could not fetch list of apps from the App Store." : "ئەپ دۇكىنىدىن ئەپلەرنىڭ تىزىملىكىنى ئالالمىدى.",
     "App download or installation failed" : "ئەپ چۈشۈرۈش ياكى قاچىلاش مەغلۇب بولدى",
     "Cannot install this app because it is not compatible" : "ماس كەلمىگەچكە بۇ ئەپنى قاچىلىغىلى بولمايدۇ",
     "Cannot install this app" : "بۇ ئەپنى قاچىلىغىلى بولمايدۇ",
     "Skip" : "ئاتلاش",
+    "Installing apps …" : "ئەپلەرنى قاچىلاش…",
     "Install recommended apps" : "تەۋسىيە قىلىنغان ئەپلەرنى قاچىلاڭ",
     "Avatar of {displayName}" : "Av displayName of نىڭ باش سۈرىتى",
     "Settings menu" : "تەڭشەك تىزىملىكى",
+    "Loading your contacts …" : "ئالاقىداشلىرىڭىزنى يۈكلەۋاتىدۇ…",
+    "Looking for {term} …" : "ئىزدەۋاتقان {term}…",
     "Search contacts" : "ئالاقىداشلارنى ئىزدە",
     "Reset search" : "ئىزدەشنى ئەسلىگە كەلتۈرۈڭ",
+    "Search contacts …" : "ئالاقىداشلارنى ئىزدەش…",
     "Could not load your contacts" : "ئالاقىداشلىرىڭىزنى يۈكلىيەلمىدى",
     "No contacts found" : "ئالاقىداش تېپىلمىدى",
     "Show all contacts" : "بارلىق ئالاقىنى كۆرسەت",
@@ -173,6 +191,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "{type} نى ئىزدەۋاتقاندا خاتالىق كۆرۈلدى",
     "Search starts once you start typing and results may be reached with the arrow keys" : "ئىزدەشنى باشلىغاندىن كېيىن ئىزدەش باشلىنىدۇ ، يا ئوق كۇنۇپكىسى بىلەن نەتىجىگە ئېرىشكىلى بولىدۇ",
     "Search for {name} only" : "پەقەت {name} نىلا ئىزدەڭ",
+    "Loading more results …" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەۋاتىدۇ…",
     "Forgot password?" : "پارولنى ئۇنتۇپ قالدىڭىزمۇ؟",
     "Back to login form" : "كىرىش جەدۋىلىگە قايتىڭ",
     "Back" : "قايتىش",
@@ -194,6 +213,7 @@ OC.L10N.register(
     "Database tablespace" : "ساندان جەدۋىلى",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "باش ئاپپارات ئىسمى بىلەن بىللە پورت نومۇرىنى بەلگىلىۈڭ (مەسىلەن ، localhost: 5432).",
     "Database host" : "ساندان مۇلازىمېتىرى",
+    "Installing …" : "قاچىلاش…",
     "Install" : "قاچىلاش",
     "Need help?" : "ياردەمگە ئېھتىياجلىقمۇ؟",
     "See the documentation" : "ھۆججەتلەرنى كۆرۈڭ",
@@ -202,6 +222,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "توركۆرگۈڭىزنى قوللىمايدۇ. يېڭى نەشرىگە ياكى قوللايدىغان نەشرىگە يېڭىلاڭ.",
     "Continue with this unsupported browser" : "بۇ قوللىمايدىغان توركۆرگۈ بىلەن داۋاملاشتۇرۇڭ",
     "Supported versions" : "قوللايدىغان نەشرى",
+    "Search {types} …" : "ئىزدەش {types}…",
     "Choose {file}" : "{file} نى تاللاڭ",
     "Choose" : "تاللاڭ",
     "Copy to {target}" : "{target} غا كۆچۈرۈڭ",
@@ -220,7 +241,7 @@ OC.L10N.register(
     "(all selected)" : "(ھەممىسى تاللانغان)",
     "({count} selected)" : "({count} تاللانغان)",
     "Error loading file exists template" : "ھۆججەت يۈكلەشتە خاتالىق بار",
-    "Saving …" : "Saving…",
+    "Saving …" : "Saving…",
     "seconds ago" : "سېكۇنت بۇرۇن",
     "Connection to server lost" : "مۇلازىمېتىرغا ئۇلىنىش يوقاپ كەتتى",
     "Add to a project" : "بىر تۈرگە قوشۇڭ",
@@ -234,8 +255,17 @@ OC.L10N.register(
     "Type to search for existing projects" : "مەۋجۇت تۈرلەرنى ئىزدەش ئۈچۈن كىرگۈزۈڭ",
     "New in" : "يېڭى",
     "View changelog" : "Changelog نى كۆرۈڭ",
+    "No action available" : "ھەرىكەت يوق",
+    "Error fetching contact actions" : "ئالاقىلىشىش ھەرىكىتىنى ئېلىپ بېرىشتا خاتالىق",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" سۆزلىشىش رامكىسىنى تاقاڭ",
     "Email length is at max (255)" : "ئېلېكترونلۇق خەتنىڭ ئۇزۇنلۇقى ئەڭ يۇقىرى بولغاندا (255)",
+    "Non-existing tag #{tag}" : "مەۋجۇت بولمىغان بەلگە # {tag}",
+    "Restricted" : "چەكلەنگەن",
+    "Invisible" : "كۆرۈنمەيدۇ",
+    "Delete" : "ئۆچۈر",
+    "Rename" : "ئات ئۆزگەرت",
+    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
+    "No tags found" : "خەتكۈچ تېپىلمىدى",
     "Personal" : "شەخسىي",
     "Accounts" : "ھېسابات",
     "Admin" : "باشقۇرغۇچى",
@@ -321,43 +351,17 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ئەگەر بۇ ئۇچۇر داۋاملاشسا ياكى ئويلىمىغان يەردىن سىستېما باشقۇرغۇچى بىلەن ئالاقىلىشىڭ.",
     "Error occurred while checking server setup" : "مۇلازىمېتىرنىڭ تەڭشىكىنى تەكشۈرگەندە خاتالىق كۆرۈلدى",
     "For more details see the {linkstart}documentation ↗{linkend}." : "تېخىمۇ كۆپ تەپسىلاتلارنى {linkstart} ھۆججەت ↗ {linkend} see دىن كۆرۈڭ.",
-    "unknown text" : "نامەلۇم تېكىست",
-    "Hello world!" : "ياخشىمۇسىز دۇنيا!",
-    "sunny" : "ئاپتاپپەرەس",
-    "Hello {name}, the weather is {weather}" : "ياخشىمۇسىز {name} ، ھاۋارايى {weather}",
-    "Hello {name}" : "ياخشىمۇسىز {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong> بۇلار سىزنىڭ ئىزدەش نەتىجىلىرىڭىز <script> ئاگاھلاندۇرۇش (1) </script> </strong>",
-    "new" : "new",
-    "Searching …" : "ئىزدەش…",
-    "Logging in …" : "تىزىمغا كىرىش…",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "تور كۆرگۈڭىزدە ۋە كۆچمە ئەپلەر بىلەن پاراڭلىشىش ، سىنلىق سۆزلىشىش ، ئېكراندىن ئورتاقلىشىش ، توردىكى ئۇچرىشىش ۋە تور يىغىنى.",
-    "Loading apps …" : "ئەپلەرنى يۈكلەۋاتىدۇ…",
-    "Installing apps …" : "ئەپلەرنى قاچىلاش…",
-    "Loading your contacts …" : "ئالاقىداشلىرىڭىزنى يۈكلەۋاتىدۇ…",
-    "Looking for {term} …" : "ئىزدەۋاتقان {term}…",
-    "Search contacts …" : "ئالاقىداشلارنى ئىزدەش…",
-    "Loading more results …" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەۋاتىدۇ…",
     "You have not added any info yet" : "سىز تېخى ھېچقانداق ئۇچۇر قوشمىدىڭىز",
     "{user} has not added any info yet" : "{user} تېخى ھېچقانداق ئۇچۇر قوشمىدى",
     "Error opening the user status modal, try hard refreshing the page" : "ئىشلەتكۈچى ھالىتى ھالىتىنى ئېچىشتا خاتالىق ، بەتنى يېڭىلاشنى سىناپ بېقىڭ",
     "Edit Profile" : "ئارخىپنى تەھرىرلەش",
     "The headline and about sections will show up here" : "ماۋزۇ ۋە بۆلەكلەر بۇ يەردە كۆرسىتىلىدۇ",
-    "Search {types} …" : "ئىزدەش {types}…",
-    "Saving …" : "Saving…",
     "Very weak password" : "پارول بەك ئاجىز",
     "Weak password" : "پارول ئاجىز",
     "So-so password" : "شۇڭا مەخپىي نومۇر",
     "Good password" : "ياخشى پارول",
     "Strong password" : "كۈچلۈك پارول",
-    "No action available" : "ھەرىكەت يوق",
-    "Error fetching contact actions" : "ئالاقىلىشىش ھەرىكىتىنى ئېلىپ بېرىشتا خاتالىق",
-    "Non-existing tag #{tag}" : "مەۋجۇت بولمىغان بەلگە # {tag}",
-    "Restricted" : "چەكلەنگەن",
-    "Invisible" : "كۆرۈنمەيدۇ",
-    "Delete" : "ئۆچۈر",
-    "Rename" : "ئات ئۆزگەرت",
-    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
-    "No tags found" : "خەتكۈچ تېپىلمىدى",
     "Profile not found" : "ئارخىپ تېپىلمىدى",
     "The profile does not exist." : "ئارخىپ مەۋجۇت ئەمەس.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".Htaccess ھۆججىتى ئىشلىمىگەچكە ، سانلىق مەلۇمات مۇندەرىجىسىڭىز ۋە ھۆججەتلىرىڭىزنى توردىن زىيارەت قىلىشىڭىز مۇمكىن.",
@@ -367,7 +371,6 @@ OC.L10N.register(
     "Configure the database" : "سانداننى سەپلەڭ",
     "Only %s is available." : "پەقەت% s نىلا ئىشلەتكىلى بولىدۇ.",
     "Database account" : "ساندان ھېساباتى",
-    "Installing …" : "قاچىلاش…",
     "Direct link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن بىۋاسىتە ئۇلىنىش"
 },
 "nplurals=2; plural=(n != 1);");
