@@ -105,7 +105,7 @@ OC.L10N.register(
     "Profile picture" : "Εικόνα προφίλ",
     "About" : "Σχετικά με",
     "Headline" : "Τίτλος",
-    "Organisation" : "Οργανισμός",
+    "Organization" : "Οργανισμός",
     "Role" : "Ρόλος/Θέση",
     "Pronouns" : "Αντωνυμίες",
     "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
@@ -188,8 +188,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού δικαιώματα εγγραφής στον κατάλογο config. Δείτε το%s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ή εάν επιθυμείτε να διατηρήσετε το config.php σε κατάσταση ανάγνωσης μόνο, καθορίστε το από τις επιλογές του σε true του \"config_is_read_only\". Δείτε %s",
-    "Cannot write into \"apps\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον κατάλογο apps ή απενεργοποιώντας το App Store στο αρχείο διαμόρφωσης config.",
     "Cannot create \"data\" directory." : "Δεν είναι δυνατή η δημιουργία καταλόγου \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού δικαιώματα εγγραφής στον ριζικό κατάλογο. Δείτε το%s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Τα δικαιώματα μπορούν συνήθως να διορθωθούν δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον ριζικό κατάλογο. Δείτε το%s.",
@@ -200,8 +198,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Παρακαλούμε ζητήστε από το διαχειριστή του διακομιστή σας να εγκαταστήσει τη μονάδα.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Η ρύθμιση \"%s\"της PHP δεν είναι ορισμένη σε \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Προσαρμόζοντας αυτήν τη ρύθμιση στο php.ini το Nextcloud θα εκτελεστεί ξανά",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Το <code>mbstring.func_overload</code> έχει ορισθεί σε <code>%s</code> αντί για την αναμενόμενη τιμή <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Η PHP φαίνεται να είναι ρυθμισμένη ώστε να αφαιρεί inline doc blocks. Αυτό θα καταστήσει πολλές βασικές εφαρμογές μη διαθέσιμες.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Κάποια αρθρώματα της PHP έχουν εγκατασταθεί, αλλά είναι ακόμα καταγεγραμμένες ως εκλιπόντα;",
@@ -222,8 +218,9 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Ο χώρος αποθήκευσης δεν είναι διαθέσιμος προσωρινά",
     "Storage connection timeout. %s" : "Λήξη χρονικού ορίου σύνδεσης με αποθηκευτικό χώρο.%s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Για να επιτρέψετε αυτόν τον έλεγχο, πρέπει να βεβαιωθείτε ότι ο διακομιστής σας μπορεί να συνδεθεί με τον εαυτό του. Επομένως, πρέπει να μπορεί να επιλύσει και να συνδεθεί με τουλάχιστον ένα από τα `trusted_domains` ή το `overwrite.cli.url`. Αυτή η αποτυχία μπορεί να οφείλεται σε αντιστοιχία DNS από την πλευρά του διακομιστή ή σε κανόνα τείχους προστασίας εξερχομένων.",
-    "Confirmation" : "Επιβεβαίωση",
+    "Images" : "Εικόνες",
     "Generated response" : "Δημιουργημένη απάντηση",
+    "Confirmation" : "Επιβεβαίωση",
     "Change Tone" : "Αλλαγή Τόνου",
     "Write a text that you want the assistant to rewrite in another tone." : "Γράψτε ένα κείμενο που θέλετε ο βοηθός να ξαναγράψει σε διαφορετικό τόνο.",
     "Desired tone" : "Επιθυμητός τόνος",
@@ -233,7 +230,12 @@ OC.L10N.register(
     "Summary" : "Σύνοψη",
     "Translate" : "Μετάφραση",
     "Result" : "Αποτέλεσμα",
+    "Organisation" : "Οργανισμός",
     "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλούμε προσπαθήστε αργότερα",
-    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου"
+    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου",
+    "Cannot write into \"apps\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον κατάλογο apps ή απενεργοποιώντας το App Store στο αρχείο διαμόρφωσης config.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Το <code>mbstring.func_overload</code> έχει ορισθεί σε <code>%s</code> αντί για την αναμενόμενη τιμή <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini."
 },
 "nplurals=2; plural=(n != 1);");
