@@ -108,7 +108,7 @@ OC.L10N.register(
     "About" : "About",
     "Display name" : "Display name",
     "Headline" : "Headline",
-    "Organisation" : "Organisation",
+    "Organization" : "Organization",
     "Role" : "Role",
     "Additional settings" : "Additional settings",
     "Enter the database name for %s" : "Enter the database name for %s",
@@ -192,8 +192,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Cannot write into \"config\" directory.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "This can usually be fixed by giving the web server write access to the config directory. See %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s",
-    "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
     "Cannot create \"data\" directory." : "Cannot create \"data\" directory.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "This can usually be fixed by giving the web server write access to the root directory. See %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permissions can usually be fixed by giving the web server write access to the root directory. See %s.",
@@ -204,8 +202,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Adjusting this setting in php.ini will make Nextcloud run again",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
@@ -226,6 +222,8 @@ OC.L10N.register(
     "Storage connection error. %s" : "Storage connection error. %s",
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Storage connection timeout. %s" : "Storage connection timeout. %s",
+    "Images" : "Images",
+    "Question" : "Question",
     "Chat" : "Chat",
     "Generates a possible headline for a text." : "Generates a possible headline for a text.",
     "Text" : "Text",
@@ -239,20 +237,12 @@ OC.L10N.register(
     "Generate headline" : "Generate headline",
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
-    "Education Edition" : "Education Edition",
-    "File name is a reserved word" : "File name is a reserved word",
-    "File name contains at least one invalid character" : "File name contains at least one invalid character",
-    "File name is too long" : "File name is too long",
-    "Users" : "Users",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
-    "Open »%s«" : "Open »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s shared »%2$s« with you",
-    "%1$s shared »%2$s« with you." : "%1$s shared »%2$s« with you.",
-    "Click the button below to open it." : "Click the button below to open it.",
+    "Organisation" : "Organisation",
     "File is currently busy, please try again later" : "File is currently busy, please try again later",
     "Cannot download file" : "Cannot download file",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory."
+    "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini."
 },
 "nplurals=2; plural=(n!=1);");
