@@ -53,6 +53,7 @@ OC.L10N.register(
     "Files" : "Bestanden",
     "View profile" : "Bekijk profiel",
     "_%nh_::_%nh_" : ["%nh","%nh"],
+    "Local time: %s" : "Lokale tijd: %s",
     "today" : "vandaag",
     "tomorrow" : "morgen",
     "yesterday" : "gisteren",
@@ -75,10 +76,14 @@ OC.L10N.register(
     "Empty file" : "Leeg bestand",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met ID: %s bestaat niet. Schakel die in binnen de app-instellingen of neem contact op met je beheerder.",
     "Dot files are not allowed" : "Punt-bestanden zijn niet toegestaan",
+    "%1$s (renamed)" : "%1$s (hernoemd)",
+    "renamed file" : "bestand hernoemd",
+    "Invalid parent path" : "Ongeldig bovenliggend pad",
     "File already exists" : "Bestand bestaat al",
     "Invalid path" : "Ongeldig pad",
     "Failed to create file from template" : "Kon geen bestand van het sjabloon maken",
     "Templates" : "Sjablonen",
+    "Path contains invalid segments" : "Pad bevat ongeldige segmenten",
     "Filename contains at least one invalid character" : "De bestandsnaam bevat ten minste één ongeldig teken",
     "Empty filename is not allowed" : "Een lege bestandsnaam is niet toegestaan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" kan niet worden geïnstalleerd, omdat het app info bestand niet gelezen kan worden.",
@@ -103,8 +108,9 @@ OC.L10N.register(
     "Address" : "Adres",
     "Profile picture" : "Profielafbeelding",
     "About" : "Over",
+    "Display name" : "Weergave naam",
     "Headline" : "Hoofdlijn",
-    "Organisation" : "Organisatie",
+    "Organization" : "Organisatie",
     "Role" : "Rol",
     "Additional settings" : "Aanvullende instellingen",
     "You need to enter details of an existing account." : "Geef de details van een bestaand account op.",
@@ -117,7 +123,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "De gedeelde achtergrond %s moet de OCP\\Share_Backend interface implementeren",
     "Sharing backend %s not found" : "De gedeelde backend %s is niet gevonden",
     "Sharing backend for %s not found" : "De gedeelde backend voor %s is niet gevonden",
+    "%1$s shared %2$s with you" : "%1$s deelde %2$s met jou",
+    "Open %s" : "%s openen",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s deelde %2$s met jou en wil toevoegen:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s deelde %2$s met jou en wil toevoegen",
+    "%s added a note to a file shared with you" : "%s heeft een notitie toegevoegd aan een bestand dat met jou werd gedeeld",
     "Unknown share type" : "Onbekend type gedeelde folder",
     "You are not allowed to share %s" : "Je bent niet bevoegd om %s te delen",
     "Cannot increase permissions of %s" : "Kan de machtiging van %s niet verhogen.",
@@ -126,6 +137,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan de vervaldatum niet meer dan %s dag in de toekomst instellen","Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen"],
     "Sharing is only allowed with group members" : "Delen kan alleen met groepsleden",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Het delen van%s is mislukt, omdat dit item al gedeeld wordt met het account %s",
     "The requested share does not exist anymore" : "De toegang tot de gedeelde folder bestaat niet meer",
     "Could not find category \"%s\"" : "Kan categorie \"%s\" niet vinden",
     "Sunday" : "Zondag",
@@ -184,8 +196,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan niet schrijven naar de \"config\" directory!",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. Zie %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Of, als je liever config.php Alleen-lezen houdt, stel de optie  \"config_is_read_only\" in op true. Zie %s",
-    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
     "Cannot create \"data\" directory." : "Kan de \"data\"-map niet aanmaken.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Machtigingen kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
@@ -196,8 +206,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Vraag je beheerder om de module te installeren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP instelling \"%s\" staat niet op \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Het aanpassen van deze instelling in php.ini zorgt ervoor dat Nextcloud weer start",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is ingesteld op <code>%s</code> in plaats van de verwachte waarde <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Om dit op te lossen stel je <code>mbstring.func_overload</code> in op <code>0</code> in je php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is nu zo ingesteld dat 'inline doc blocks' worden gestript. Hierdoor worden verschillende hoofd modules onbruikbaar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
@@ -216,11 +224,18 @@ OC.L10N.register(
     "Storage connection error. %s" : "Opslag verbindingsfout. %s",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
+    "Images" : "Afbeeldingen",
+    "Question" : "Vraag",
     "Confirmation" : "Bevestiging",
     "Text" : "Tekst",
     "Summary" : "Samenvatting",
     "Translate" : "Vertaal",
     "Result" : "Resultaat",
-    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw"
+    "Organisation" : "Organisatie",
+    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
+    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is ingesteld op <code>%s</code> in plaats van de verwachte waarde <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Om dit op te lossen stel je <code>mbstring.func_overload</code> in op <code>0</code> in je php.ini."
 },
 "nplurals=2; plural=(n != 1);");
