@@ -38,7 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Sunucu %s ya da daha sonraki bir sürüm olmalıdır.",
     "Server version %s or lower is required." : "Sunucu %s ya da daha önceki bir sürüm olmalıdır.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış hesap bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
-    "Your current IP address doesn’t allow you to perform admin actions" : "Geçerli IP adresiniz yönetici işlemleri yapmanıza izin vermiyor",
+    "Your current IP address doesn't allow you to perform admin actions" : "Geçerli IP adresiniz yönetici işlemleri yapmanıza izin vermiyor",
     "Logged in account must be an admin or sub admin" : "Oturum açmış hesap bir yönetici ya da alt yönetici olmalıdır",
     "Logged in account must be an admin" : "Oturum açmış hesap bir yönetici olmalıdır",
     "Wiping of device %s has started" : "%s aygıtının silinmesine başlandı",
@@ -59,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Avatar görseli kare değil",
     "Files" : "Dosyalar",
     "View profile" : "Profili görüntüle",
+    "same time" : "aynı zamanda",
+    "_%nh_::_%nh_" : ["%ns","%ns"],
+    "_%nm_::_%nm_" : ["%nd","%nd"],
+    "%s ahead" : "%s ileride",
+    "%s behind" : "%s geride",
     "Local time: %s" : "Yerel zaman: %s",
     "today" : "bugün",
     "tomorrow" : "yarın",
@@ -78,10 +83,18 @@ OC.L10N.register(
     "_in %n minute_::_in %n minutes_" : ["%n dakika içinde","%n dakika içinde"],
     "_%n minute ago_::_%n minutes ago_" : ["%n dakika önce","%n dakika önce"],
     "in a few seconds" : "bir kaç saniye içinde",
-    "seconds ago" : "saniyeler önce",
+    "seconds ago" : "saniye önce",
     "Empty file" : "Dosya boş",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül bulunamadı. Lütfen uygulamalarınız içinden modülü kullanıma alın ya da BT yöneticiniz ile görüşün.",
+    "No file conversion providers available" : "Kullanılabilecek bir dosya dönüştürücü hizmeti sağlayıcı yok",
+    "File is too large to convert" : "Dosya dönüştürülmek için çok büyük",
+    "Destination does not match conversion extension" : "Hedef dönüştürme eklentisiyle eşleşmiyor",
+    "Could not convert file" : "Dosya dönüştürülemedi",
+    "Destination does not exist" : "Hedef bulunamadı",
+    "Destination is not creatable" : "Hedef oluşturulamadı",
     "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
+    "%1$s (renamed)" : "%1$s (yeniden adlandırıldı)",
+    "renamed file" : "dosyayı yeniden adlandırdı",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" dosya ya da klasör adı olarak kullanılamaz.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" dosya ya da klasör adı ön eki olarak kullanılamaz.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" bir dosya ya da klasör adında kullanılamaz.",
@@ -92,6 +105,13 @@ OC.L10N.register(
     "Invalid path" : "Yol geçersiz",
     "Failed to create file from template" : "Kalıptan dosya oluşturulamadı",
     "Templates" : "Kalıplar",
+    "Storage %s cannot be moved" : "%s depolama alanı taşınamadı",
+    "Moving a share (%s) into a shared folder is not allowed" : "Bir paylaşımın (%s) paylaşılan bir klasöre taşınmasına izin verilmiyor",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Bir depolama alanının (%s) paylaşılan bir klasöre taşınmasına izin verilmiyor",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Bir paylaşımın (%s) başka bir paylaşıma (%s) taşınmasına izin verilmiyor",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Bir paylaşımın (%s) başka bir depolama alanına (%s) taşınmasına izin verilmiyor",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Bir depolama alanının (%s) başka bir paylaşıma (%s) taşınmasına izin verilmiyor",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Bir depolama alanının (%s) başka bir depolama alanına (%s) taşınmasına izin verilmiyor",
     "Path contains invalid segments" : "Yolda geçersiz bölümler var",
     "Filename is a reserved word" : "Dosya adı sistem kullanımına ayrılmış bir sözcük",
     "Filename contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
@@ -109,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Ayarlar",
     "Log out" : "Oturumu kapat",
     "Accounts" : "Hesaplar",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Bluesky üzerinde görüntüle: %s",
     "Email" : "E-posta",
     "Mail %s" : "E-posta gönder: %s",
     "Fediverse" : "Fediverse",
@@ -116,7 +138,7 @@ OC.L10N.register(
     "Phone" : "Telefon",
     "Call %s" : "Çağrı gönder: %s",
     "Twitter" : "Twitter",
-    "View %s on Twitter" : "Twitter üzerinde bak: %s",
+    "View %s on Twitter" : "Twitter üzerinde görüntüle: %s",
     "Website" : "Site",
     "Visit %s" : "Siteyi aç: %s",
     "Address" : "Adres",
@@ -124,7 +146,7 @@ OC.L10N.register(
     "About" : "Hakkında",
     "Display name" : "Görüntülenecek ad",
     "Headline" : "Başlık",
-    "Organisation" : "Kuruluş",
+    "Organization" : "Kuruluş",
     "Role" : "Pozisyon",
     "Pronouns" : "Hitaplar",
     "Unknown account" : "Hesap bilinmiyor",
@@ -138,25 +160,23 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle ile bağlantı kurulamadı",
     "Oracle Login and/or password not valid" : "Oracle kullanıcı adı ve/veya parolası geçersiz",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL kullanıcı adı ve/veya parolası geçersiz",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
     "For the best results, please consider using a GNU/Linux server instead." : "En iyi sonucu almak için GNU/Linux sunucusu kullanın.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
     "Set an admin Login." : "Bir yönetici kullanıcı adı yazın.",
     "Set an admin password." : "Bir yönetici parolası yazın.",
     "Cannot create or write into the data directory %s" : "%s veri klasörü oluşturulamadı ya da içine yazılamadı",
-    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
-    "Sharing backend %s not found" : "%s paylaşım arka ucu bulunamadı",
-    "Sharing backend for %s not found" : "%s için paylaşım arka ucu bulunamadı",
-    "%1$s shared »%2$s« with you" : "%1$s, sizinle »%2$s« ögesini paylaştı",
-    "%1$s shared »%2$s« with you." : "%1$s, sizinle »%2$s« ögesini paylaştı.",
-    "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
-    "Open »%s«" : "»%s« aç",
+    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka yüzü %s OCP\\Share_Backend arayüzünü desteklemeli",
+    "Sharing backend %s not found" : "%s paylaşım arka yüzü bulunamadı",
+    "Sharing backend for %s not found" : "%s için paylaşım arka yüzü bulunamadı",
+    "%1$s shared %2$s with you" : "%1$s, sizinle %2$s ögesini paylaştı",
+    "Open %s" : "%s ögesini aç",
     "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor",
-    "»%s« added a note to a file shared with you" : "»%s« sizinle paylaştığı bir dosyaya bir not ekledi",
-    "Passwords are enforced for link and mail shares" : "Bağlantı ve e-posta paylaşımları için parolalar zorunludur",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s sizinle %2$s ögesini paylaştı ve eklemenizi istiyor:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s sizinle %2$s ögesini paylaştı ve eklemenizi istiyor",
+    "%s added a note to a file shared with you" : "%s sizinle paylaştığı bir dosyaya bir not ekledi",
+    "Passwords are enforced for link and mail shares" : "Bağlantı ve e-posta paylaşımları için parola kullanılması zorunlu kılınmış",
     "Share recipient is not a valid user" : "Paylaşım alıcısı geçerli bir kullanıcı değil",
     "Share recipient is not a valid group" : "Paylaşım alıcısı geçerli bir grup değil",
     "Share recipient should be empty" : "Paylaşım alıcısı boş olmalı",
@@ -170,12 +190,13 @@ OC.L10N.register(
     "You cannot share your root folder" : "Kök klasörünüzü paylaşamazsınız",
     "You are not allowed to share %s" : "%s ögesini paylaşma izniniz yok",
     "Valid permissions are required for sharing" : "Paylaşım için geçerli izinler olmalıdır",
+    "File shares cannot have create or delete permissions" : "Dosya paylaşımlarında oluşturma ya da silme izni olamaz",
     "Cannot increase permissions of %s" : "%s izinleri yükseltilemedi",
     "Shares need at least read permissions" : "Paylaşımların en azından okuma izinleri olmalıdır",
     "Files cannot be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
     "Files cannot be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
     "Expiration date is in the past" : "Geçerlilik sonu tarihi geçmişte",
-    "Expiration date is enforced" : "Geçerlilik sonu tarihi dayatılıyor",
+    "Expiration date is enforced" : "Geçerlilik sonu tarihi zorunlu kılınmış",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz","Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz"],
     "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
     "Sharing %s failed, because this item is already shared with the account %s" : "%s paylaşılamadı. Bu öge zaten %s hesabı ile paylaşılmış",
@@ -184,16 +205,16 @@ OC.L10N.register(
     "Path is already shared with this group" : "Bu yol bu grup ile zaten paylaşılmış",
     "Link sharing is not allowed" : "Bağlantı paylaşımına izin verilmiyor",
     "Public upload is not allowed" : "Herkese açık yüklemeye izin verilmiyor",
-    "Path contains files shared with you" : "Yolda sizinle paylaşılmış dosyalar var",
+    "You cannot share a folder that contains other shares" : "Başka paylaşımların bulunduğu bir klasörü paylaşamazsınız",
     "Sharing is disabled" : "Paylaşım kullanımdan kaldırılmış",
     "Sharing is disabled for you" : "Paylaşım sizin için kullanımdan kaldırılmış",
     "Cannot share with the share owner" : "Paylaşımı sahibi ile paylaşamazsınız",
     "Share does not have a full ID" : "Paylaşımın tam kimliği yok",
     "Cannot change share type" : "Paylaşım türü değiştirilemez",
     "Can only update recipient on user shares" : "Yalnızca kullanıcı paylaşımlarındaki alıcıyı güncelleyebilir",
-    "Cannot enable sending the password by Talk with an empty password" : "Boş bir parola ile Sohbet uygulaması ile parola gönderme özelliği kullanıma alınamaz",
-    "Cannot enable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Sohbet uygulaması ile parola gönderme özelliği kullanıma alınamaz",
-    "Cannot disable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Sohbet uygulaması ile parola gönderme kullanımdan kaldırılamaz",
+    "Cannot enable sending the password by Talk with an empty password" : "Boş bir parola kullanarak Konuş uygulaması ile parola gönderme özelliği açılamaz",
+    "Cannot enable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Konuş uygulaması ile parola gönderme özelliği açılamaz",
+    "Cannot disable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Konuş uygulaması ile parola gönderme özelliği kapatılamaz",
     "Share provider does not support accepting" : "Paylaşım hizmeti sağlayıcısı kabul etmeyi desteklemiyor",
     "Cannot change target of link share" : "Bağlantı paylaşımının hedefi değiştirilemedi",
     "Invalid share recipient" : "Paylaşım alıcısı geçersiz",
@@ -202,8 +223,8 @@ OC.L10N.register(
     "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım kullanımdan kaldırılmış bir kullanıcıdan geliyor",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
-    "Input text" : "Giriş metni",
-    "The input text" : "Giriş metni",
+    "Input text" : "Giriş yazısı",
+    "The input text" : "Giriş yazısı",
     "Sunday" : "Pazar",
     "Monday" : "Pazartesi",
     "Tuesday" : "Salı",
@@ -256,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
     "Login contains whitespace at the beginning or at the end" : "Kullanıcı adının başında ya da sonunda boşluk var",
     "Login must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
+    "Username is too long" : "Kullanıcı adı çok uzun",
     "Login is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
     "Account disabled" : "Hesap kullanımdan kaldırılmış",
     "Login canceled by app" : "Oturum açma uygulama tarafından iptal edildi",
@@ -268,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "\"config\" klasörüne yazılamadı.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Bu sorun genellikle, site sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın. %s bölümüne bakabilirsiniz",
-    "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası kullanımdan kaldırılarak çözülebilir.",
     "Cannot create \"data\" directory." : "\"data\" klasörü oluşturulamadı",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Bu sorun genellikle, site sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "İzinler genellikle, site sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
@@ -280,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Lütfen modülü kurması için BT yöneticiniz ile görüşün.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ayarı \"%s\" olarak ayarlanmamış.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini dosyasında bu ayar yapıldığında Nextcloud yeniden çalışır",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP girintili doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu durum bazı çekirdek uygulamalarına erişilmesini engelleyecek.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu sorun genellikle Zend OPcache ya da eAccelerator gibi bir ön bellek/hızlandırıcı nedeniyle ortaya çıkar.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri kurulmuş, ancak hala eksik olarak mı görünüyor?",
@@ -306,25 +324,61 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
     "Storage connection timeout. %s" : "Depolama bağlantısı zaman aşımı. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Bu denetimi çalıştırabilmek için site sunucunuzun kendisine bağlanabildiğinden emin olmanız gerekir. Bu nedenle, `trusted_domains` ya da `overwrite.cli.url` değerlerinden en az birini çözümleyebilmeli ve bunlara bağlanabilmelidir. Bu sorun, sunucu tarafındaki bir DNS uyumsuzluğunun veya giden güvenlik duvarı kuralının sonucu olabilir.",
+    "Analyze images" : "Görselleri incele",
+    "Ask a question about the given images." : "Verilen görseller ile ilgili bir soru sorun.",
+    "Images" : "Görseller",
+    "Images to ask a question about" : "Haklarında bir soru sorulacak görseller",
+    "Question" : "Soru",
+    "What to ask about the images." : "Görseller hakkında ne sorulacağı.",
+    "Generated response" : "Üretilen yanıt",
+    "The answer to the question" : "Sorunun yanıtı",
+    "Audio chat" : "Sesli görüşme",
+    "Voice chat with the assistant" : "Yardımcı ile sesli görüşme",
+    "System prompt" : "Sistem istemi",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Görüşme sırasında yardımcının uyması gereken kuralları ve varsayımları tanımlayın.",
+    "Chat voice message" : "Görüşme ses iletisi",
+    "Describe a task that you want the assistant to do or ask a question." : "Yardımcının yapmasını istediğiniz bir görevi tanımlayın ya da bir soru sorun.",
+    "Chat history" : "Sohbet geçmişi",
+    "The history of chat messages before the current message, starting with a message by the user." : "Kullanıcının iletisiyle başlayarak, geçerli iletiden önceki sohbet iletilerinin geçmişi.",
+    "Input transcript" : "Girişin yazıya dökümü",
+    "Transcription of the audio input" : "Ses girişinin yazıya dökümü",
+    "Response voice message" : "Yanıt ses iletisi",
+    "The generated voice response as part of the conversation" : "Sesli görüşmenin parçası olarak oluşturulan yanıt",
+    "Output transcript" : "Çıkışın yazıya dökümü",
+    "Transcription of the audio output" : "Ses çıkışının yazıya dökümü",
     "Transcribe audio" : "Sesten yazıya dönüştür.",
     "Transcribe the things said in an audio" : "Bir sestekileri yazıya dönüştür",
     "Audio input" : "Ses girişi",
     "The audio to transcribe" : "Yazıya dönüştürülecek ses",
     "Transcription" : "Yazıya dönüştürme",
     "The transcribed text" : "Dönüştürülen yazı",
+    "Chat by voice with an agent" : "Bir aracı ile sesli görüşün",
+    "Describe a task that you want the agent to do or ask a question." : "Aracının yapmasını istediğiniz bir görevi tanımlayın ya da bir soru sorun.",
+    "Confirmation" : "Onaylama",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Daha önce istenilen işlemlerin onaylanıp onaylanmayacağı: Reddedilmesi için 0, onaylanması için 1.",
+    "Conversation token" : "Görüşme kodu",
+    "A token representing the conversation." : "Görüşmenin kodu.",
+    "The new conversation token" : "Yeni görüşme kodu",
+    "Send this along with the next interaction." : "Bunu sonraki etkileşimin yanında gönderin.",
+    "Requested actions by the agent" : "Aracı tarafından istenilen işlemler",
+    "Actions that the agent would like to carry out in JSON format." : "Aracının JSON biçiminde gerçekleştirmesi istenen işlemler.",
+    "Chat with an agent" : "Bir aracı ile sohbet edin",
+    "Chat message" : "Sohbet iletisi",
+    "A chat message to send to the agent." : "Aracıya gönderilecek sohbet iletisi.",
+    "The response from the chat model." : "Sohbet modelinin yanıtı.",
     "Context write" : "Bağlam yazma",
-    "Writes text in a given style based on the provided source material." : "Sağlanan kaynak materyale göre belirli bir tarzda metin yazar.",
+    "Writes text in a given style based on the provided source material." : "Sağlanan kaynak materyale göre belirli bir tarzda yazı oluşturur.",
     "Writing style" : "Yazma tarzı",
     "Demonstrate a writing style that you would like to immitate" : "Taklit etmek isteyeceğiniz bir yazım tarzını gösterin",
     "Source material" : "Kaynak materyal",
     "The content that would like to be rewritten in the new writing style" : "Yeni yazım tarzında yeniden yazılması istenen içerik",
-    "Generated text" : "Oluşturulan metin",
-    "The generated text with content from the source material in the given style" : "Kaynak materyal içeriği ile belirtilen tarzda oluşturulan metin",
+    "Generated text" : "Oluşturulan yazı",
+    "The generated text with content from the source material in the given style" : "Kaynak materyal içeriği ile belirtilen tarzda oluşturulan yazı",
     "Emoji generator" : "Duygu ifadesi oluşturma",
-    "Takes text and generates a representative emoji for it." : "Metni alır ve onu temsil eden bir duygu ifadesi oluşturur.",
-    "The text to generate an emoji for" : "Duygu ifadesi oluşturulacak metin",
+    "Takes text and generates a representative emoji for it." : "Yazıyı alır ve onu temsil eden bir duygu ifadesi oluşturur.",
+    "The text to generate an emoji for" : "Duygu ifadesi oluşturulacak yazı",
     "Generated emoji" : "Oluşturulan duygu ifadesi",
-    "The generated emoji based on the input text" : "Giriş metnine göre oluşturulan duygu ifadesi",
+    "The generated emoji based on the input text" : "Giriş yazısına göre oluşturulan duygu ifadesi",
     "Generate image" : "Görsel oluştur",
     "Generate an image from a text prompt" : "Bir yazıdan bir duygu ifadesi oluştur",
     "Prompt" : "Soru",
@@ -333,94 +387,94 @@ OC.L10N.register(
     "How many images to generate" : "Oluşturulacak görsel sayısı",
     "Output images" : "Çıktı görselleri",
     "The generated images" : "Oluşturulan görseller",
+    "Generate speech" : "Konuşma oluştur",
+    "Generate speech from a transcript" : "Bir yazıya dönüştürmeden konuşma oluştur",
+    "Write transcript that you want the assistant to generate speech from" : "Yardımcının konuşma oluşturmasını istediğiniz yazı dönüştürmesini yazın",
+    "Output speech" : "Konuşma çıktısı",
+    "The generated speech" : "Oluşturulan konuşma",
     "Free text to text prompt" : "Ücretsiz yazıdan yazıya istemi",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Dil modeli ile bir yanıt döndüren isteğe bağlı bir bilgi istemi çalıştırır",
     "Describe a task that you want the assistant to do or ask a question" : "Yardımcının yapmasını istediğiniz bir görevi tanımlayın ya da bir soru sorun",
     "Generated reply" : "Oluşturulan yanıt",
-    "The generated text from the assistant" : "Yardımcının oluşturduğu metin",
+    "The generated text from the assistant" : "Yardımcının oluşturduğu yazı",
+    "Change Tone" : "Tonu değiştir",
+    "Change the tone of a piece of text." : "Bir yazı parçasının tonunu değiştirir.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Yardımcının başka bir tonda yeniden yazmasını istediğiniz bir yazı yazın",
+    "Desired tone" : "İstenilen ton",
+    "In which tone should your text be rewritten?" : "Yazı hangi tonda yeniden yazılmalı?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Yardımcı tarafından istenilen tonda yeniden oluşturulan yazı:",
     "Chat" : "Sohbet",
     "Chat with the assistant" : "Yardımcı ile sohbet et",
-    "System prompt" : "Sistem istemi",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Sohbet sırasında yardımcının uyması gereken kuralları ve varsayımları tanımlayın.",
-    "Chat message" : "Sohbet iletisi",
-    "Chat history" : "Sohbet geçmişi",
     "The history of chat messages before the current message, starting with a message by the user" : "Kullanıcının iletisiyle başlayarak, geçerli iletiden önceki sohbet iletilerinin geçmişi",
     "Response message" : "Yanıt iletisi",
-    "The generated response as part of the conversation" : "Sohbetin parçası olarak oluşturulan yanıt",
-    "Formalize text" : "Metni resmileştir",
-    "Takes a text and makes it sound more formal" : "Bir metni alarak daha resmi dile dönüştürür",
-    "Write a text that you want the assistant to formalize" : "Yardımcının resmileştirmesini istediğiniz bir metin yazın",
-    "Formalized text" : "Resmileştirilmiş metin",
-    "The formalized text" : "Resmileştirilmiş metin",
+    "The generated response as part of the conversation" : "Görüşmenin parçası olarak oluşturulan yanıt",
+    "Chat with tools" : "Araçlar ile sohbet",
+    "Chat with the language model with tool calling support." : "Araç çağırma desteği ile dil modeliyle sohbet edin.",
+    "Tool message" : "Araç iletisi",
+    "The result of tool calls in the last interaction" : "Son etkileşimdeki araç çağrılarının sonucu",
+    "Available tools" : "Kullanılabilecek araçlar",
+    "The available tools in JSON format" : "JSON biçiminde kullanılabilecek araçlar",
+    "The response from the chat model" : "Sohbet modelinin yanıtı",
+    "Tool calls" : "Araç çağrıları",
+    "Tools call instructions from the model in JSON format" : "Araçlar, modelden JSON biçiminde komutları çağırır",
+    "Formalize text" : "Yazıyı resmileştir",
+    "Takes a text and makes it sound more formal" : "Bir yazıyı alarak daha resmi dile dönüştürür",
+    "Write a text that you want the assistant to formalize" : "Yardımcının resmileştirmesini istediğiniz bir yazı yazın",
+    "Formalized text" : "Resmileştirilmiş yazı",
+    "The formalized text" : "Resmileştirilmiş yazı",
     "Generate a headline" : "Bir başlık oluştur",
-    "Generates a possible headline for a text." : "Bir metin için olası bir başlık oluşturur.",
-    "Original text" : "Özgün metin",
-    "The original text to generate a headline for" : "Başlık oluşturulacak metin",
+    "Generates a possible headline for a text." : "Bir yazı için olası bir başlık oluşturur.",
+    "Original text" : "Özgün yazı",
+    "The original text to generate a headline for" : "Başlık oluşturulacak yazı",
     "The generated headline" : "Oluşturulan başlık",
-    "Reformulate text" : "Metni yeniden düzenle",
-    "Takes a text and reformulates it" : "Bir metni alarak yeniden düzenler",
-    "Write a text that you want the assistant to reformulate" : "Yardımcının yeniden düzenlemesini istediğiniz bir metin yazın",
-    "Reformulated text" : "Yeniden düzenlenmiş metin",
-    "The reformulated text, written by the assistant" : "Yardımcı tarafından yazılan yeniden düzenlenmiş metin",
-    "Simplify text" : "Metni basitleştir",
-    "Takes a text and simplifies it" : "Bir metni alarak basitleştirir",
-    "Write a text that you want the assistant to simplify" : "Yardımcının basitleştirmesini istediğiniz bir metin yazın",
-    "Simplified text" : "Basitleştirilmiş metin",
-    "The simplified text" : "Basitleştirilmiş metin",
+    "Proofread" : "Düzelt",
+    "Proofreads a text and lists corrections" : "Bir yazıyı düzeltir ve düzeltmeleri listeler",
+    "Text" : "Yazı",
+    "The text to proofread" : "Düzeltilecek yazı",
+    "Corrections" : "Düzeltmeler",
+    "The corrections that should be made in your text" : "Yazınızda yapılması gereken düzeltmeler",
+    "Reformulate text" : "Yazıyı yeniden düzenle",
+    "Takes a text and reformulates it" : "Bir yazıyı alarak yeniden düzenler",
+    "Write a text that you want the assistant to reformulate" : "Yardımcının yeniden düzenlemesini istediğiniz bir yazı yazın",
+    "Reformulated text" : "Yeniden düzenlenmiş yazı",
+    "The reformulated text, written by the assistant" : "Yardımcı tarafından yazılan yeniden düzenlenmiş yazı",
+    "Simplify text" : "Yazıyı basitleştir",
+    "Takes a text and simplifies it" : "Bir yazıyı alarak basitleştirir",
+    "Write a text that you want the assistant to simplify" : "Yardımcının basitleştirmesini istediğiniz bir yazı yazın",
+    "Simplified text" : "Basitleştirilmiş yazı",
+    "The simplified text" : "Basitleştirilmiş yazı",
     "Summarize" : "Özetlensin",
-    "Summarizes a text" : "Bir metni özetler",
-    "The original text to summarize" : "Özetlenecek özgün metin",
+    "Summarizes a text" : "Bir yazıyı özetler",
+    "The original text to summarize" : "Özetlenecek özgün yazı",
     "Summary" : "Özet",
     "The generated summary" : "Oluşturulan özet",
     "Extract topics" : "Başlıklar ayıklansın",
-    "Extracts topics from a text and outputs them separated by commas" : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar",
-    "The original text to extract topics from" : "Konuların ayıklanacağı özgün metin",
+    "Extracts topics from a text and outputs them separated by commas" : "Bir yazıdaki konuları ayıklar ve bunları virgül ile ayırarak sıralar",
+    "The original text to extract topics from" : "Konuların ayıklanacağı özgün yazı",
     "Topics" : "Konular",
     "The list of extracted topics" : "Ayıklanan konuların listesi",
     "Translate" : "Çevir",
-    "Translate text from one language to another" : "Metni bir dilden diğerine çevir",
-    "Origin text" : "Kaynak metin",
-    "The text to translate" : "Çevrilecek metin",
+    "Translate text from one language to another" : "Yazıyı bir dilden diğerine çevir",
+    "Origin text" : "Kaynak yazı",
+    "The text to translate" : "Çevrilecek yazı",
     "Origin language" : "Kaynak dil",
-    "The language of the origin text" : "Kaynak metnin dili",
+    "The language of the origin text" : "Kaynak yazının dili",
     "Target language" : "Hedef dil",
-    "The desired language to translate the origin text in" : "Kaynak metnin çevrilmesini istediğiniz dil",
+    "The desired language to translate the origin text in" : "Kaynak yazının çevrilmesini istediğiniz dil",
     "Result" : "Sonuç",
-    "The translated text" : "Çevrilmiş metin",
+    "The translated text" : "Çevrilmiş yazı",
     "Free prompt" : "Ücretsiz bilgi istemi",
     "Runs an arbitrary prompt through the language model." : "Dil modeli ile isteğe bağlı bir bilgi istemi çalıştırır.",
     "Generate headline" : "Başlık oluşturulsun",
-    "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak metni özetler.",
-    "Extracts topics from a text and outputs them separated by commas." : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
-    "Education Edition" : "Eğitim sürümü",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
-    "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
-    "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
-    "File name is a reserved word" : "Bu dosya adı sistem kullanıma ayrılmıştır",
-    "File name contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
-    "File name is too long" : "Dosya adı çok uzun",
-    "Help" : "Yardım",
-    "Users" : "Kullanıcılar",
-    "Unknown user" : "Kullanıcı bilinmiyor",
-    "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
-    "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
-    "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
-    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
-    "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
-    "The username is already being used" : "Bu kullanıcı adı zaten var",
-    "Could not create user" : "Kullanıcı oluşturulamadı",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
-    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
-    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
-    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
-    "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
-    "User disabled" : "Kullanıcı kullanımdan kaldırılmış",
+    "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak yazıyı özetler.",
+    "Extracts topics from a text and outputs them separated by commas." : "Bir yazıdaki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
+    "Organisation" : "Kuruluş",
     "File is currently busy, please try again later" : "Dosya şu anda meşgul. Lütfen bir süre sonra yeniden deneyin",
     "Cannot download file" : "Dosya indirilemedi",
-    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun."
+    "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası kullanımdan kaldırılarak çözülebilir.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın.",
+    "Login is too long" : "Kullanıcı adı çok uzun"
 },
 "nplurals=2; plural=(n > 1);");
